@@ -19,6 +19,7 @@ package org.apache.seatunnel.api.table.factory;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 
 import lombok.Getter;
 
@@ -27,10 +28,10 @@ import java.util.Map;
 @Getter
 public class MultiTableFactoryContext extends TableSinkFactoryContext {
 
-    private final Map<String, SeaTunnelSink> sinks;
+    private final Map<TablePath, SeaTunnelSink> sinks;
 
     public MultiTableFactoryContext(
-            ReadonlyConfig options, ClassLoader classLoader, Map<String, SeaTunnelSink> sinks) {
+            ReadonlyConfig options, ClassLoader classLoader, Map<TablePath, SeaTunnelSink> sinks) {
         super(null, options, classLoader);
         this.sinks = sinks;
     }
