@@ -169,7 +169,6 @@ public final class SeaTunnelRow implements Serializable {
                 if (elementType instanceof DecimalType) {
                     return ((Object[]) v).length * 36;
                 }
-
                 if (elementType instanceof LocalTimeType) {
                     SqlType eleSqlType = elementType.getSqlType();
                     switch (eleSqlType) {
@@ -232,6 +231,8 @@ public final class SeaTunnelRow implements Serializable {
                 return getArrayNotNullSize((Long[]) v) * 8;
             case DOUBLE:
                 return getArrayNotNullSize((Double[]) v) * 8;
+            case MAP:
+                return getArrayMapNotNullSize(v);
             case NULL:
             default:
                 return 0;
@@ -248,6 +249,19 @@ public final class SeaTunnelRow implements Serializable {
         return c;
     }
 
+    private int getArrayMapNotNullSize(Object v) {
+        int size = 0;
+        if (Objects.nonNull(v)) {
+            for (Map o : (Map[]) v) {
+                for (Map.Entry<?, ?> entry : ((Map<?, ?>) o).entrySet()) {
+                    size += getBytesForValue(entry.getKey()) + getBytesForValue(entry.getValue());
+                }
+            }
+        }
+
+        return size;
+    }
+
     public int getBytesSize() {
         if (size == 0) {
             int s = 0;
@@ -305,6 +319,9 @@ public final class SeaTunnelRow implements Serializable {
                 return getBytesForArray(v, BasicType.FLOAT_TYPE);
             case "Double[]":
                 return getBytesForArray(v, BasicType.DOUBLE_TYPE);
+            case "Map[]":
+                return getBytesForArray(
+                        v, new MapType<>(BasicType.STRING_TYPE, BasicType.INT_TYPE));
             case "HashMap":
             case "LinkedHashMap":
                 int size = 0;
