@@ -20,7 +20,10 @@ package org.apache.seatunnel.connectors.seatunnel.assertion.exception;
 import org.apache.seatunnel.common.exception.SeaTunnelErrorCode;
 
 public enum AssertConnectorErrorCode implements SeaTunnelErrorCode {
-    RULE_VALIDATION_FAILED("ASSERT-01", "Rule validate failed");
+    RULE_VALIDATION_FAILED("ASSERT-01", "Rule validate failed"),
+    TYPES_NOT_SUPPORTED_FAILED("ASSERT-02", "Types not supported"),
+    CATALOG_TABLE_FAILED("ASSERT-03", "Catalog table failed"),
+    ;
 
     private final String code;
     private final String description;
