@@ -23,9 +23,9 @@ import org.apache.seatunnel.shade.com.typesafe.config.ConfigException;
 import org.apache.seatunnel.shade.com.typesafe.config.ConfigFactory;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
+import org.apache.seatunnel.api.options.ConnectorCommonOptions;
 import org.apache.seatunnel.api.sink.SinkWriter;
 import org.apache.seatunnel.api.sink.SupportMultiTableSink;
-import org.apache.seatunnel.api.table.catalog.CatalogOptions;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
@@ -41,12 +41,11 @@ import java.util.Map;
 import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
 
-import static org.apache.seatunnel.api.table.catalog.schema.TableSchemaOptions.TABLE_CONFIGS;
 import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertConfig.CATALOG_TABLE_RULES;
 import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertConfig.FIELD_RULES;
 import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertConfig.ROW_RULES;
-import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertConfig.RULES;
 import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertConfig.TABLE_PATH;
+import static org.apache.seatunnel.connectors.seatunnel.assertion.sink.AssertSinkOptions.RULES;
 
 public class AssertSink extends AbstractSimpleSink<SeaTunnelRow, Void>
         implements SupportMultiTableSink {
@@ -68,10 +67,11 @@ public class AssertSink extends AbstractSimpleSink<SeaTunnelRow, Void>
         assertCatalogTableRule = new ConcurrentHashMap<>();
         catalogTableName = catalogTable.getTablePath().getFullName();
         Config ruleConfig = ConfigFactory.parseMap(pluginConfig.get(RULES));
-        if (ruleConfig.hasPath(TABLE_CONFIGS.key())) {
-            List<? extends Config> tableConfigs = ruleConfig.getConfigList(TABLE_CONFIGS.key());
+        if (ruleConfig.hasPath(ConnectorCommonOptions.TABLE_CONFIGS.key())) {
+            List<? extends Config> tableConfigs =
+                    ruleConfig.getConfigList(ConnectorCommonOptions.TABLE_CONFIGS.key());
             for (Config tableConfig : tableConfigs) {
-                String tableName = tableConfig.getString(TABLE_PATH.key());
+                String tableName = tableConfig.getString(TABLE_PATH);
                 initTableRule(catalogTable, tableConfig, tableName);
             }
         } else {
@@ -79,9 +79,10 @@ public class AssertSink extends AbstractSimpleSink<SeaTunnelRow, Void>
             initTableRule(catalogTable, ruleConfig, tableName);
         }
 
-        if (ruleConfig.hasPath(CatalogOptions.TABLE_NAMES.key())) {
+        if (ruleConfig.hasPath(ConnectorCommonOptions.TABLE_NAMES.key())) {
             assertTableRule =
-                    new AssertTableRule(ruleConfig.getStringList(CatalogOptions.TABLE_NAMES.key()));
+                    new AssertTableRule(
+                            ruleConfig.getStringList(ConnectorCommonOptions.TABLE_NAMES.key()));
         } else {
             assertTableRule = new AssertTableRule(new ArrayList<>());
         }
