@@ -50,6 +50,7 @@ import static org.apache.seatunnel.connectors.cdc.base.source.split.wartermark.W
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.getFetchTimestamp;
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.getMessageTimestamp;
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isDataChangeRecord;
+import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isHeartbeatRecord;
 import static org.apache.seatunnel.connectors.cdc.base.utils.SourceRecordUtils.isSchemaChangeEvent;
 
 /**
@@ -144,7 +145,7 @@ public class IncrementalSourceRecordEmitter<T>
             Offset position = getOffsetPosition(element);
             splitState.asIncrementalSplitState().setStartupOffset(position);
             emitElement(element, output);
-        } else if (isDataChangeRecord(element)) {
+        } else if (isDataChangeRecord(element) || isHeartbeatRecord(element)) {
             if (splitState.isIncrementalSplitState()) {
                 Offset position = getOffsetPosition(element);
                 splitState.asIncrementalSplitState().setStartupOffset(position);
