@@ -20,6 +20,7 @@ package org.apache.seatunnel.connectors.seatunnel.cdc.mysql.config;
 import org.apache.seatunnel.connectors.cdc.base.option.JdbcSourceOptions;
 
 import java.io.Serializable;
+import java.util.Random;
 
 import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkArgument;
 
@@ -83,7 +84,11 @@ public class ServerIdRange implements Serializable {
      */
     public static ServerIdRange from(String range) {
         if (range == null) {
-            return null;
+            long start = (new Random().nextInt(Integer.MAX_VALUE)) + 6500L;
+            // 1024000 is the maybe max number of parallelism
+            // mysql server id should be in range [1, 2^32-1]
+            long end = start + 1024000L;
+            return new ServerIdRange(start, end);
         }
         if (range.contains("-")) {
             String[] idArray = range.split("-");
