@@ -17,6 +17,8 @@
 
 package io.debezium.connector.oracle.logminer;
 
+import org.apache.seatunnel.connectors.seatunnel.cdc.oracle.config.OracleSourceConfigFactory;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -33,6 +35,7 @@ import io.debezium.connector.oracle.Scn;
 import io.debezium.connector.oracle.logminer.logwriter.CommitLogWriterFlushStrategy;
 import io.debezium.connector.oracle.logminer.logwriter.LogWriterFlushStrategy;
 import io.debezium.connector.oracle.logminer.logwriter.RacCommitLogWriterFlushStrategy;
+import io.debezium.connector.oracle.logminer.logwriter.ReadOnlyLogWriterFlushStrategy;
 import io.debezium.connector.oracle.logminer.processor.LogMinerEventProcessor;
 import io.debezium.jdbc.JdbcConfiguration;
 import io.debezium.pipeline.ErrorHandler;
@@ -1012,7 +1015,12 @@ public class LogMinerStreamingChangeEventSource
      *
      * @return the strategy to be used to flush Oracle's LGWR process, never {@code null}.
      */
-    private LogWriterFlushStrategy resolveFlushStrategy() {
+    public LogWriterFlushStrategy resolveFlushStrategy() {
+        if (connectorConfig
+                .getConfig()
+                .getBoolean(OracleSourceConfigFactory.LOG_MINING_READONLY_KEY, false)) {
+            return new ReadOnlyLogWriterFlushStrategy();
+        }
         if (connectorConfig.isRacSystem()) {
             return new RacCommitLogWriterFlushStrategy(
                     connectorConfig, jdbcConfiguration, streamingMetrics);
