@@ -22,11 +22,13 @@ import lombok.Getter;
 import lombok.Setter;
 import lombok.ToString;
 
+import java.io.Serializable;
+
 @Setter
 @Getter
 @ToString
 @EqualsAndHashCode
-public class DorisSinkState {
+public class DorisSinkState implements Serializable {
     private final String labelPrefix;
     private final long checkpointId;
 
