@@ -17,9 +17,10 @@
 
 package org.apache.seatunnel.connectors.seatunnel.elasticsearch.dto;
 
+import org.apache.seatunnel.shade.com.google.common.base.Strings;
+
 import org.apache.seatunnel.connectors.seatunnel.elasticsearch.constant.ElasticsearchVersion;
 
-import com.google.common.base.Strings;
 import lombok.Builder;
 import lombok.Getter;
 import lombok.ToString;
