@@ -18,8 +18,6 @@
 package org.apache.seatunnel.connectors.seatunnel.fake.source;
 
 import org.apache.seatunnel.api.source.SourceSplitEnumerator;
-import org.apache.seatunnel.api.source.event.EnumeratorCloseEvent;
-import org.apache.seatunnel.api.source.event.EnumeratorOpenEvent;
 import org.apache.seatunnel.connectors.seatunnel.fake.config.FakeConfig;
 import org.apache.seatunnel.connectors.seatunnel.fake.config.MultipleTableFakeSourceConfig;
 import org.apache.seatunnel.connectors.seatunnel.fake.state.FakeSourceState;
@@ -58,9 +56,7 @@ public class FakeSourceSplitEnumerator
     }
 
     @Override
-    public void open() {
-        enumeratorContext.getEventListener().onEvent(new EnumeratorOpenEvent());
-    }
+    public void open() {}
 
     @Override
     public void run() throws Exception {
@@ -69,9 +65,7 @@ public class FakeSourceSplitEnumerator
     }
 
     @Override
-    public void close() throws IOException {
-        enumeratorContext.getEventListener().onEvent(new EnumeratorCloseEvent());
-    }
+    public void close() throws IOException {}
 
     @Override
     public void addSplitsBack(List<FakeSourceSplit> splits, int subtaskId) {
