@@ -26,6 +26,7 @@ import org.apache.seatunnel.connectors.seatunnel.file.config.BaseSinkConfig;
 import org.apache.seatunnel.connectors.seatunnel.file.config.FileFormat;
 import org.apache.seatunnel.connectors.seatunnel.file.config.PartitionConfig;
 import org.apache.seatunnel.connectors.seatunnel.file.exception.FileConnectorException;
+import org.apache.seatunnel.format.csv.constant.CsvStringQuoteMode;
 
 import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
@@ -86,6 +87,9 @@ public class FileSinkConfig extends BaseFileSinkConfig implements PartitionConfi
     private List<String> parquetAvroWriteFixedAsInt96 =
             BaseSinkConfig.PARQUET_AVRO_WRITE_FIXED_AS_INT96.defaultValue();
 
+    private CsvStringQuoteMode csvStringQuoteMode =
+            BaseSinkConfig.CSV_STRING_QUOTE_MODE.defaultValue();
+
     public FileSinkConfig(@NonNull Config config, @NonNull SeaTunnelRowType seaTunnelRowTypeInfo) {
         super(config);
         checkArgument(
@@ -205,9 +209,7 @@ public class FileSinkConfig extends BaseFileSinkConfig implements PartitionConfi
             this.sheetName = config.getString(BaseSinkConfig.SHEET_NAME.key());
         }
 
-        if (FileFormat.XML
-                .name()
-                .equalsIgnoreCase(config.getString(BaseSinkConfig.FILE_FORMAT_TYPE.key()))) {
+        if (FileFormat.XML.equals(this.fileFormat)) {
             if (!config.hasPath(BaseSinkConfig.XML_USE_ATTR_FORMAT.key())) {
                 throw new FileConnectorException(
                         CommonErrorCodeDeprecated.ILLEGAL_ARGUMENT,
@@ -225,9 +227,7 @@ public class FileSinkConfig extends BaseFileSinkConfig implements PartitionConfi
             }
         }
 
-        if (FileFormat.PARQUET
-                .name()
-                .equalsIgnoreCase(config.getString(BaseSinkConfig.FILE_FORMAT_TYPE.key()))) {
+        if (FileFormat.PARQUET.equals(this.fileFormat)) {
             if (config.hasPath(BaseSinkConfig.PARQUET_AVRO_WRITE_TIMESTAMP_AS_INT96.key())) {
                 this.parquetWriteTimestampAsInt96 =
                         config.getBoolean(
@@ -239,5 +239,13 @@ public class FileSinkConfig extends BaseFileSinkConfig implements PartitionConfi
                                 BaseSinkConfig.PARQUET_AVRO_WRITE_FIXED_AS_INT96.key());
             }
         }
+
+        if (FileFormat.CSV.equals(this.fileFormat)) {
+            if (config.hasPath(BaseSinkConfig.CSV_STRING_QUOTE_MODE.key())) {
+                this.csvStringQuoteMode =
+                        CsvStringQuoteMode.valueOf(
+                                config.getString(BaseSinkConfig.CSV_STRING_QUOTE_MODE.key()));
+            }
+        }
     }
 }
