@@ -44,6 +44,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import lombok.NonNull;
+import lombok.SneakyThrows;
 
 import java.io.File;
 import java.io.IOException;
@@ -59,7 +60,7 @@ import java.util.UUID;
 import java.util.regex.Matcher;
 import java.util.stream.Collectors;
 
-public abstract class AbstractWriteStrategy implements WriteStrategy {
+public abstract class AbstractWriteStrategy<T> implements WriteStrategy<T> {
     protected final Logger log = LoggerFactory.getLogger(this.getClass());
     protected final FileSinkConfig fileSinkConfig;
     protected final CompressFormat compressFormat;
@@ -82,6 +83,7 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
     protected Long checkpointId = 0L;
     protected int partId = 0;
     protected int batchSize;
+    protected boolean singleFileMode;
     protected int currentBatchSize = 0;
 
     public AbstractWriteStrategy(FileSinkConfig fileSinkConfig) {
@@ -89,6 +91,7 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
         this.sinkColumnsIndexInRow = fileSinkConfig.getSinkColumnsIndexInRow();
         this.batchSize = fileSinkConfig.getBatchSize();
         this.compressFormat = fileSinkConfig.getCompressFormat();
+        this.singleFileMode = fileSinkConfig.isSingleFileMode();
     }
 
     /**
@@ -107,7 +110,7 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
 
     @Override
     public void write(SeaTunnelRow seaTunnelRow) throws FileConnectorException {
-        if (currentBatchSize >= batchSize) {
+        if (currentBatchSize >= batchSize && !singleFileMode) {
             newFilePart();
             currentBatchSize = 0;
         }
@@ -218,11 +221,19 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
      * @return file name
      */
     @Override
-    public String generateFileName(String transactionId) {
+    public final String generateFileName(String transactionId) {
         String fileNameExpression = fileSinkConfig.getFileNameExpression();
         FileFormat fileFormat = fileSinkConfig.getFileFormat();
-        String suffix = fileFormat.getSuffix();
-        suffix = compressFormat.getCompressCodec() + suffix;
+        String suffix;
+        if (StringUtils.isNotEmpty(fileSinkConfig.getFilenameExtension())) {
+            suffix =
+                    fileSinkConfig.getFilenameExtension().startsWith(".")
+                            ? fileSinkConfig.getFilenameExtension()
+                            : "." + fileSinkConfig.getFilenameExtension();
+        } else {
+            suffix = fileFormat.getSuffix();
+            suffix = compressFormat.getCompressCodec() + suffix;
+        }
         if (StringUtils.isBlank(fileNameExpression)) {
             return transactionId + suffix;
         }
@@ -234,8 +245,10 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
         valuesMap.put(Constants.NOW, formattedDate);
         valuesMap.put(timeFormat, formattedDate);
         valuesMap.put(BaseSinkConfig.TRANSACTION_EXPRESSION, transactionId);
-        String substitute =
-                VariablesSubstitute.substitute(fileNameExpression, valuesMap) + "_" + partId;
+        String substitute = VariablesSubstitute.substitute(fileNameExpression, valuesMap);
+        if (!singleFileMode) {
+            substitute += "_" + partId;
+        }
         return substitute + suffix;
     }
 
@@ -244,8 +257,13 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
      *
      * @return the file commit information
      */
+    @SneakyThrows
     @Override
     public Optional<FileCommitInfo> prepareCommit() {
+        if (this.needMoveFiles.isEmpty() && fileSinkConfig.isCreateEmptyFileWhenNoData()) {
+            String filePath = createFilePathWithoutPartition();
+            this.getOrCreateOutputStream(filePath);
+        }
         this.finishAndCloseFile();
         LinkedHashMap<String, String> commitMap = new LinkedHashMap<>(this.needMoveFiles);
         LinkedHashMap<String, List<String>> copyMap =
@@ -357,10 +375,25 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
         return String.join(File.separator, strings);
     }
 
+    public String createFilePathWithoutPartition() {
+        return getPathWithPartitionInfo(null, true);
+    }
+
     public String getOrCreateFilePathBeingWritten(@NonNull SeaTunnelRow seaTunnelRow) {
         LinkedHashMap<String, List<String>> dataPartitionDirAndValuesMap =
                 generatorPartitionDir(seaTunnelRow);
-        String beingWrittenFileKey = dataPartitionDirAndValuesMap.keySet().toArray()[0].toString();
+        boolean noPartition =
+                BaseSinkConfig.NON_PARTITION.equals(
+                        dataPartitionDirAndValuesMap.keySet().toArray()[0].toString());
+        return getPathWithPartitionInfo(dataPartitionDirAndValuesMap, noPartition);
+    }
+
+    private String getPathWithPartitionInfo(
+            LinkedHashMap<String, List<String>> dataPartitionDirAndValuesMap, boolean noPartition) {
+        String beingWrittenFileKey =
+                noPartition
+                        ? BaseSinkConfig.NON_PARTITION
+                        : dataPartitionDirAndValuesMap.keySet().toArray()[0].toString();
         // get filePath from beingWrittenFile
         String beingWrittenFilePath = beingWrittenFile.get(beingWrittenFileKey);
         if (beingWrittenFilePath != null) {
@@ -372,8 +405,7 @@ public abstract class AbstractWriteStrategy implements WriteStrategy {
                     };
             String newBeingWrittenFilePath = String.join(File.separator, pathSegments);
             beingWrittenFile.put(beingWrittenFileKey, newBeingWrittenFilePath);
-            if (!BaseSinkConfig.NON_PARTITION.equals(
-                    dataPartitionDirAndValuesMap.keySet().toArray()[0].toString())) {
+            if (!noPartition) {
                 partitionDirAndValuesMap.putAll(dataPartitionDirAndValuesMap);
             }
             return newBeingWrittenFilePath;
