@@ -59,7 +59,7 @@ import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 
-public class OrcWriteStrategy extends AbstractWriteStrategy {
+public class OrcWriteStrategy extends AbstractWriteStrategy<Writer> {
     private final LinkedHashMap<String, Writer> beingWrittenWriter;
 
     public OrcWriteStrategy(FileSinkConfig fileSinkConfig) {
@@ -71,7 +71,7 @@ public class OrcWriteStrategy extends AbstractWriteStrategy {
     public void write(@NonNull SeaTunnelRow seaTunnelRow) {
         super.write(seaTunnelRow);
         String filePath = getOrCreateFilePathBeingWritten(seaTunnelRow);
-        Writer writer = getOrCreateWriter(filePath);
+        Writer writer = getOrCreateOutputStream(filePath);
         TypeDescription schema = buildSchemaWithRowType();
         VectorizedRowBatch rowBatch = schema.createRowBatch();
         int i = 0;
@@ -109,7 +109,8 @@ public class OrcWriteStrategy extends AbstractWriteStrategy {
         this.beingWrittenWriter.clear();
     }
 
-    private Writer getOrCreateWriter(@NonNull String filePath) {
+    @Override
+    public Writer getOrCreateOutputStream(@NonNull String filePath) {
         Writer writer = this.beingWrittenWriter.get(filePath);
         if (writer == null) {
             TypeDescription schema = buildSchemaWithRowType();
