@@ -35,6 +35,7 @@ import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.commons.compress.compressors.gzip.GzipCompressorInputStream;
 import org.apache.commons.compress.compressors.gzip.GzipParameters;
+import org.apache.commons.lang3.StringUtils;
 import org.apache.hadoop.fs.FileStatus;
 
 import lombok.extern.slf4j.Slf4j;
@@ -80,7 +81,7 @@ public abstract class AbstractReadStrategy implements ReadStrategy {
     protected List<String> readColumns = new ArrayList<>();
     protected boolean isMergePartition = true;
     protected long skipHeaderNumber = BaseSourceConfigOptions.SKIP_HEADER_ROW_NUMBER.defaultValue();
-    protected transient boolean isKerberosAuthorization = false;
+    protected String filenameExtension;
     protected HadoopFileSystemProxy hadoopFileSystemProxy;
     protected ArchiveCompressFormat archiveCompressFormat =
             BaseSourceConfigOptions.ARCHIVE_COMPRESS_CODEC.defaultValue();
@@ -136,7 +137,10 @@ public abstract class AbstractReadStrategy implements ReadStrategy {
                 }
             }
         }
-
+        if (StringUtils.isNotEmpty(filenameExtension)) {
+            this.fileNames.removeIf(fileName -> !fileName.endsWith(filenameExtension));
+            fileNames.removeIf(fileName -> !fileName.endsWith(filenameExtension));
+        }
         return fileNames;
     }
 
@@ -159,6 +163,10 @@ public abstract class AbstractReadStrategy implements ReadStrategy {
             skipHeaderNumber =
                     pluginConfig.getLong(BaseSourceConfigOptions.SKIP_HEADER_ROW_NUMBER.key());
         }
+        if (pluginConfig.hasPath(BaseSourceConfigOptions.FILENAME_EXTENSION.key())) {
+            filenameExtension =
+                    pluginConfig.getString(BaseSourceConfigOptions.FILENAME_EXTENSION.key());
+        }
         if (pluginConfig.hasPath(BaseSourceConfigOptions.READ_PARTITIONS.key())) {
             readPartitions.addAll(
                     pluginConfig.getStringList(BaseSourceConfigOptions.READ_PARTITIONS.key()));
