@@ -23,14 +23,24 @@ import org.apache.seatunnel.connectors.seatunnel.file.config.FileSystemType;
 import org.apache.seatunnel.connectors.seatunnel.file.local.config.LocalFileHadoopConf;
 import org.apache.seatunnel.connectors.seatunnel.file.sink.BaseMultipleTableFileSink;
 
+import java.util.Optional;
+
 public class LocalFileSink extends BaseMultipleTableFileSink {
 
+    private final CatalogTable catalogTable;
+
     public LocalFileSink(ReadonlyConfig readonlyConfig, CatalogTable catalogTable) {
         super(new LocalFileHadoopConf(), readonlyConfig, catalogTable);
+        this.catalogTable = catalogTable;
     }
 
     @Override
     public String getPluginName() {
         return FileSystemType.LOCAL.getFileSystemPluginName();
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return Optional.ofNullable(catalogTable);
+    }
 }
