@@ -18,13 +18,12 @@
 package org.apache.seatunnel.connectors.seatunnel.http.sink;
 
 import org.apache.seatunnel.api.configuration.util.OptionRule;
-import org.apache.seatunnel.api.sink.SinkCommonOptions;
-import org.apache.seatunnel.api.table.catalog.CatalogTable;
+import org.apache.seatunnel.api.options.SinkConnectorCommonOptions;
 import org.apache.seatunnel.api.table.connector.TableSink;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactory;
 import org.apache.seatunnel.api.table.factory.TableSinkFactoryContext;
-import org.apache.seatunnel.connectors.seatunnel.http.config.HttpConfig;
+import org.apache.seatunnel.connectors.seatunnel.http.config.HttpSinkOptions;
 
 import com.google.auto.service.AutoService;
 
@@ -37,19 +36,19 @@ public class HttpSinkFactory implements TableSinkFactory {
 
     @Override
     public TableSink createSink(TableSinkFactoryContext context) {
-        CatalogTable catalogTable = context.getCatalogTable();
-        return () -> new HttpSink(context.getOptions().toConfig(), catalogTable);
+        return () -> new HttpSink(context.getOptions(), context.getCatalogTable());
     }
 
     @Override
     public OptionRule optionRule() {
         return OptionRule.builder()
-                .required(HttpConfig.URL)
-                .optional(HttpConfig.HEADERS)
-                .optional(HttpConfig.RETRY)
-                .optional(HttpConfig.RETRY_BACKOFF_MULTIPLIER_MS)
-                .optional(HttpConfig.RETRY_BACKOFF_MAX_MS)
-                .optional(SinkCommonOptions.MULTI_TABLE_SINK_REPLICA)
+                .required(HttpSinkOptions.URL)
+                .optional(HttpSinkOptions.HEADERS)
+                .optional(HttpSinkOptions.PARAMS)
+                .optional(HttpSinkOptions.RETRY)
+                .optional(HttpSinkOptions.RETRY_BACKOFF_MULTIPLIER_MS)
+                .optional(HttpSinkOptions.RETRY_BACKOFF_MAX_MS)
+                .optional(SinkConnectorCommonOptions.MULTI_TABLE_SINK_REPLICA)
                 .build();
     }
 }
