@@ -23,7 +23,7 @@ import org.apache.seatunnel.api.source.SourceSplit;
 import org.apache.seatunnel.api.table.connector.TableSource;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableSourceFactoryContext;
-import org.apache.seatunnel.connectors.seatunnel.gitlab.source.config.GitlabSourceConfig;
+import org.apache.seatunnel.connectors.seatunnel.gitlab.source.config.GitlabSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.http.source.HttpSourceFactory;
 
 import com.google.auto.service.AutoService;
@@ -40,13 +40,11 @@ public class GitlabSourceFactory extends HttpSourceFactory {
     @Override
     public <T, SplitT extends SourceSplit, StateT extends Serializable>
             TableSource<T, SplitT, StateT> createSource(TableSourceFactoryContext context) {
-        return () ->
-                (SeaTunnelSource<T, SplitT, StateT>)
-                        new GitlabSource(context.getOptions().toConfig());
+        return () -> (SeaTunnelSource<T, SplitT, StateT>) new GitlabSource(context.getOptions());
     }
 
     @Override
     public OptionRule optionRule() {
-        return getHttpBuilder().required(GitlabSourceConfig.ACCESS_TOKEN).build();
+        return getHttpBuilder().required(GitlabSourceOptions.ACCESS_TOKEN).build();
     }
 }
