@@ -17,20 +17,14 @@
 
 package org.apache.seatunnel.connectors.seatunnel.lemlist.source;
 
-import org.apache.seatunnel.shade.com.typesafe.config.Config;
-
-import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
+import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
-import org.apache.seatunnel.common.config.CheckConfigUtil;
-import org.apache.seatunnel.common.config.CheckResult;
-import org.apache.seatunnel.common.constants.PluginType;
 import org.apache.seatunnel.connectors.seatunnel.common.source.AbstractSingleSplitReader;
 import org.apache.seatunnel.connectors.seatunnel.common.source.SingleSplitReaderContext;
 import org.apache.seatunnel.connectors.seatunnel.http.source.HttpSource;
 import org.apache.seatunnel.connectors.seatunnel.http.source.HttpSourceReader;
-import org.apache.seatunnel.connectors.seatunnel.lemlist.source.config.LemlistSourceConfig;
+import org.apache.seatunnel.connectors.seatunnel.lemlist.source.config.LemlistSourceOptions;
 import org.apache.seatunnel.connectors.seatunnel.lemlist.source.config.LemlistSourceParameter;
-import org.apache.seatunnel.connectors.seatunnel.lemlist.source.exception.LemlistConnectorException;
 
 import lombok.extern.slf4j.Slf4j;
 
@@ -40,23 +34,11 @@ import static org.apache.seatunnel.connectors.seatunnel.http.util.AuthorizationU
 public class LemlistSource extends HttpSource {
     private final LemlistSourceParameter lemlistSourceParameter = new LemlistSourceParameter();
 
-    public LemlistSource(Config pluginConfig) {
+    public LemlistSource(ReadonlyConfig pluginConfig) {
         super(pluginConfig);
-        CheckResult result =
-                CheckConfigUtil.checkAllExists(
-                        pluginConfig,
-                        LemlistSourceConfig.URL.key(),
-                        LemlistSourceConfig.PASSWORD.key());
-        if (!result.isSuccess()) {
-            throw new LemlistConnectorException(
-                    SeaTunnelAPIErrorCode.CONFIG_VALIDATION_FAILED,
-                    String.format(
-                            "PluginName: %s, PluginType: %s, Message: %s",
-                            getPluginName(), PluginType.SOURCE, result.getMsg()));
-        }
         // get accessToken by basic auth
         String accessToken =
-                getTokenByBasicAuth("", pluginConfig.getString(LemlistSourceConfig.PASSWORD.key()));
+                getTokenByBasicAuth("", pluginConfig.get(LemlistSourceOptions.PASSWORD));
         lemlistSourceParameter.buildWithConfig(pluginConfig, accessToken);
     }
 
