@@ -271,10 +271,6 @@ public abstract class AbstractJdbcCatalog implements Catalog {
         throw new UnsupportedOperationException();
     }
 
-    protected String getListSynonymSql(String databaseName) {
-        throw new UnsupportedOperationException();
-    }
-
     protected String getDatabaseWithConditionSql(String databaseName) {
         throw CommonError.unsupportedMethod(this.catalogName, "getDatabaseWithConditionSql");
     }
@@ -360,20 +356,6 @@ public abstract class AbstractJdbcCatalog implements Catalog {
         }
     }
 
-    public List<String> listSynonym(String databaseName)
-            throws CatalogException, DatabaseNotExistException {
-        if (!databaseExists(databaseName)) {
-            throw new DatabaseNotExistException(this.catalogName, databaseName);
-        }
-        String dbUrl = getUrlFromDatabaseName(databaseName);
-        try {
-            return queryString(dbUrl, getListSynonymSql(databaseName), this::getTableName);
-        } catch (Exception e) {
-            throw new CatalogException(
-                    String.format("Failed listing database in catalog %s", catalogName), e);
-        }
-    }
-
     @Override
     public boolean tableExists(TablePath tablePath) throws CatalogException {
         String databaseName = tablePath.getDatabaseName();
