@@ -35,7 +35,7 @@ import com.google.auto.service.AutoService;
 import java.util.Collections;
 import java.util.Map;
 
-import static com.google.common.base.Preconditions.checkNotNull;
+import static org.apache.seatunnel.shade.com.google.common.base.Preconditions.checkNotNull;
 
 @AutoService(DataTypeConvertor.class)
 public class SnowflakeDataTypeConvertor implements DataTypeConvertor<String> {
