@@ -18,6 +18,7 @@
 package org.apache.seatunnel.connectors.seatunnel.jdbc.internal.dialect;
 
 public class DatabaseIdentifier {
+    public static final String GENERIC = "Generic";
     public static final String DB_2 = "DB2";
     public static final String DAMENG = "Dameng";
     public static final String GBASE_8A = "Gbase8a";
@@ -42,4 +43,6 @@ public class DatabaseIdentifier {
     public static final String XUGU = "XUGU";
     public static final String IRIS = "IRIS";
     public static final String INCEPTOR = "Inceptor";
+    public static final String OPENGAUSS = "OpenGauss";
+    public static final String HIGHGO = "Highgo";
 }
