@@ -37,19 +37,29 @@ import org.apache.seatunnel.format.json.ogg.OggJsonSerializationSchema;
 import org.apache.seatunnel.format.protobuf.ProtobufSerializationSchema;
 import org.apache.seatunnel.format.text.TextSerializationSchema;
 
+import org.apache.commons.collections4.MapUtils;
 import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.common.header.Header;
+import org.apache.kafka.common.header.internals.RecordHeader;
+import org.apache.kafka.common.header.internals.RecordHeaders;
 
 import lombok.RequiredArgsConstructor;
 
+import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import java.util.List;
+import java.util.Map;
 import java.util.function.Function;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import static org.apache.seatunnel.connectors.seatunnel.kafka.config.Config.PROTOBUF_MESSAGE_NAME;
-import static org.apache.seatunnel.connectors.seatunnel.kafka.config.Config.PROTOBUF_SCHEMA;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseConstants.HEADERS;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseConstants.KEY;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseConstants.PARTITION;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseConstants.TIMESTAMP;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseConstants.VALUE;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseOptions.PROTOBUF_MESSAGE_NAME;
+import static org.apache.seatunnel.connectors.seatunnel.kafka.config.KafkaBaseOptions.PROTOBUF_SCHEMA;
 
 @RequiredArgsConstructor
 public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
@@ -71,6 +81,17 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
                 headersExtractor.apply(row));
     }
 
+    public static DefaultSeaTunnelRowSerializer create(
+            String topic, MessageFormat format, SeaTunnelRowType rowType) {
+        return new DefaultSeaTunnelRowSerializer(
+                topicExtractor(topic, rowType, format),
+                partitionNativeExtractor(rowType),
+                timestampExtractor(rowType),
+                keyExtractor(rowType),
+                valueExtractor(rowType),
+                headersExtractor(rowType));
+    }
+
     public static DefaultSeaTunnelRowSerializer create(
             String topic,
             SeaTunnelRowType rowType,
@@ -118,6 +139,11 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
                 headersExtractor());
     }
 
+    private static Function<SeaTunnelRow, Integer> partitionNativeExtractor(
+            SeaTunnelRowType rowType) {
+        return row -> (Integer) row.getField(rowType.indexOf(PARTITION));
+    }
+
     private static Function<SeaTunnelRow, Integer> partitionExtractor(Integer partition) {
         return row -> partition;
     }
@@ -126,13 +152,26 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
         return row -> null;
     }
 
+    private static Function<SeaTunnelRow, Long> timestampExtractor(SeaTunnelRowType rowType) {
+        return row -> (Long) row.getField(rowType.indexOf(TIMESTAMP));
+    }
+
     private static Function<SeaTunnelRow, Iterable<Header>> headersExtractor() {
         return row -> null;
     }
 
+    private static Function<SeaTunnelRow, Iterable<Header>> headersExtractor(
+            SeaTunnelRowType rowType) {
+
+        return row ->
+                convertToKafkaHeaders((Map<String, String>) row.getField(rowType.indexOf(HEADERS)));
+    }
+
     private static Function<SeaTunnelRow, String> topicExtractor(
             String topic, SeaTunnelRowType rowType, MessageFormat format) {
-        if (MessageFormat.COMPATIBLE_DEBEZIUM_JSON.equals(format) && topic == null) {
+        if ((MessageFormat.COMPATIBLE_DEBEZIUM_JSON.equals(format)
+                        || MessageFormat.NATIVE.equals(format))
+                && topic == null) {
             int topicFieldIndex =
                     rowType.indexOf(CompatibleDebeziumJsonDeserializationSchema.FIELD_TOPIC);
             return row -> row.getField(topicFieldIndex).toString();
@@ -188,6 +227,10 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
         return row -> serializationSchema.serialize(keyRowExtractor.apply(row));
     }
 
+    private static Function<SeaTunnelRow, byte[]> keyExtractor(SeaTunnelRowType rowType) {
+        return row -> (byte[]) row.getField(rowType.indexOf(KEY));
+    }
+
     private static Function<SeaTunnelRow, byte[]> valueExtractor(
             SeaTunnelRowType rowType,
             MessageFormat format,
@@ -198,6 +241,10 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
         return row -> serializationSchema.serialize(row);
     }
 
+    private static Function<SeaTunnelRow, byte[]> valueExtractor(SeaTunnelRowType rowType) {
+        return row -> (byte[]) row.getField(rowType.indexOf(VALUE));
+    }
+
     private static SeaTunnelRowType createKeyType(
             List<String> keyFieldNames, SeaTunnelRowType rowType) {
         int[] keyFieldIndexArr = new int[keyFieldNames.size()];
@@ -234,6 +281,7 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
             ReadonlyConfig pluginConfig) {
         switch (format) {
             case JSON:
+            case NATIVE:
                 return new JsonSerializationSchema(rowType);
             case TEXT:
                 return TextSerializationSchema.builder()
@@ -263,4 +311,17 @@ public class DefaultSeaTunnelRowSerializer implements SeaTunnelRowSerializer {
                         "Unsupported format: " + format);
         }
     }
+
+    private static Iterable<Header> convertToKafkaHeaders(Map<String, String> headersMap) {
+        if (MapUtils.isEmpty(headersMap)) {
+            return null;
+        }
+        RecordHeaders kafkaHeaders = new RecordHeaders();
+        for (Map.Entry<String, String> entry : headersMap.entrySet()) {
+            kafkaHeaders.add(
+                    new RecordHeader(
+                            entry.getKey(), entry.getValue().getBytes(StandardCharsets.UTF_8)));
+        }
+        return kafkaHeaders;
+    }
 }
