@@ -147,19 +147,23 @@ public class MaxComputeCatalog implements Catalog {
     @Override
     public CatalogTable getTable(TablePath tablePath)
             throws CatalogException, TableNotExistException {
+        return getTable(tablePath, new ArrayList<>());
+    }
+
+    @Override
+    public CatalogTable getTable(TablePath tablePath, List<String> fieldNames)
+            throws CatalogException, TableNotExistException {
         if (!tableExists(tablePath)) {
             throw new TableNotExistException(catalogName, tablePath);
         }
         Table odpsTable;
         com.aliyun.odps.TableSchema odpsSchema;
-        boolean isPartitioned;
         try {
             Odps odps = getOdps(tablePath.getDatabaseName());
             odpsTable =
                     MaxcomputeUtil.parseTable(
                             odps, tablePath.getDatabaseName(), tablePath.getTableName());
             odpsSchema = odpsTable.getSchema();
-            isPartitioned = odpsTable.isPartitioned();
         } catch (Exception ex) {
             throw new CatalogException(catalogName, ex);
         }
@@ -168,7 +172,13 @@ public class MaxComputeCatalog implements Catalog {
         buildColumnsWithErrorCheck(
                 tablePath,
                 builder,
-                odpsSchema.getColumns().iterator(),
+                odpsSchema.getColumns().stream()
+                        .filter(
+                                column ->
+                                        fieldNames == null
+                                                || fieldNames.isEmpty()
+                                                || fieldNames.contains(column.getName()))
+                        .iterator(),
                 (column) -> {
                     BasicTypeDefine<TypeInfo> typeDefine =
                             BasicTypeDefine.<TypeInfo>builder()
@@ -181,25 +191,6 @@ public class MaxComputeCatalog implements Catalog {
                                     .build();
                     return MaxComputeTypeConverter.INSTANCE.convert(typeDefine);
                 });
-        if (isPartitioned) {
-            buildColumnsWithErrorCheck(
-                    tablePath,
-                    builder,
-                    odpsSchema.getPartitionColumns().iterator(),
-                    (column) -> {
-                        BasicTypeDefine<TypeInfo> typeDefine =
-                                BasicTypeDefine.<TypeInfo>builder()
-                                        .name(column.getName())
-                                        .nativeType(column.getTypeInfo())
-                                        .columnType(column.getTypeInfo().getTypeName())
-                                        .dataType(column.getTypeInfo().getTypeName())
-                                        .nullable(column.isNullable())
-                                        .comment(column.getComment())
-                                        .build();
-                        partitionKeys.add(column.getName());
-                        return MaxComputeTypeConverter.INSTANCE.convert(typeDefine);
-                    });
-        }
         TableSchema tableSchema = builder.build();
         TableIdentifier tableIdentifier = getTableIdentifier(tablePath);
         return CatalogTable.of(
@@ -271,6 +262,27 @@ public class MaxComputeCatalog implements Catalog {
         }
     }
 
+    public void createPartition(TablePath tablePath, PartitionSpec partitionSpec) {
+        try {
+            Odps odps = getOdps(tablePath.getDatabaseName());
+            Table odpsTable = odps.tables().get(tablePath.getTableName());
+            odpsTable.createPartition(partitionSpec, true);
+        } catch (Exception e) {
+            throw new CatalogException("create partition error", e);
+        }
+    }
+
+    public void truncatePartition(TablePath tablePath, PartitionSpec partitionSpec) {
+        try {
+            Odps odps = getOdps(tablePath.getDatabaseName());
+            Table odpsTable = odps.tables().get(tablePath.getTableName());
+            odpsTable.deletePartition(partitionSpec, true);
+            odpsTable.createPartition(partitionSpec, true);
+        } catch (Exception e) {
+            throw new CatalogException("create partition error", e);
+        }
+    }
+
     @Override
     public boolean isExistsData(TablePath tablePath) {
         throw new UnsupportedOperationException();
@@ -280,7 +292,15 @@ public class MaxComputeCatalog implements Catalog {
     public void executeSql(TablePath tablePath, String sql) {
         try {
             Odps odps = getOdps(tablePath.getDatabaseName());
-            SQLTask.run(odps, sql).waitForSuccess();
+            String[] sqls = sql.split(";");
+            for (String s : sqls) {
+                if (!s.trim().isEmpty()) {
+                    if (!s.trim().endsWith(";")) {
+                        s = s.trim() + ";";
+                    }
+                    SQLTask.run(odps, s).waitForSuccess();
+                }
+            }
         } catch (OdpsException e) {
             throw new CatalogException("execute sql error", e);
         }
