@@ -18,20 +18,30 @@
 package org.apache.seatunnel.connectors.seatunnel.maxcompute.source;
 
 import org.apache.seatunnel.api.source.SourceSplit;
+import org.apache.seatunnel.api.table.catalog.TablePath;
 
+import lombok.EqualsAndHashCode;
 import lombok.Getter;
+import lombok.Setter;
 
+@Getter
+@Setter
+@EqualsAndHashCode
 public class MaxcomputeSourceSplit implements SourceSplit {
-    @Getter private int splitId;
-    @Getter private long rowNum;
+    private final long rowStart;
+    private final long rowNum;
+    private final TablePath tablePath;
+    private final int index;
 
-    public MaxcomputeSourceSplit(int splitId, long rowNum) {
-        this.splitId = splitId;
+    public MaxcomputeSourceSplit(long rowStart, long rowNum, TablePath tablePath, int index) {
+        this.rowStart = rowStart;
         this.rowNum = rowNum;
+        this.tablePath = tablePath;
+        this.index = index;
     }
 
     @Override
     public String splitId() {
-        return String.valueOf(this.splitId);
+        return tablePath.toString() + "_" + index;
     }
 }
