@@ -17,8 +17,6 @@
 
 package org.apache.seatunnel.connectors.seatunnel.maxcompute.util;
 
-import org.apache.seatunnel.shade.com.typesafe.config.Config;
-
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.table.type.ArrayType;
 import org.apache.seatunnel.api.table.type.MapType;
@@ -48,9 +46,11 @@ import java.io.Serializable;
 import java.sql.Date;
 import java.sql.Time;
 import java.sql.Timestamp;
+import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.ZoneId;
+import java.time.ZonedDateTime;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -89,8 +89,8 @@ public class MaxcomputeTypeMapper implements Serializable {
         return arrayRecord;
     }
 
-    public static SeaTunnelRowType getSeaTunnelRowType(Config pluginConfig) {
-        Table table = MaxcomputeUtil.getTable(ReadonlyConfig.fromConfig(pluginConfig));
+    public static SeaTunnelRowType getSeaTunnelRowType(ReadonlyConfig config) {
+        Table table = MaxcomputeUtil.getTable(config);
         TableSchema tableSchema = table.getSchema();
         ArrayList<SeaTunnelDataType<?>> seaTunnelDataTypes = new ArrayList<>();
         ArrayList<String> fieldNames = new ArrayList<>();
@@ -183,12 +183,21 @@ public class MaxcomputeTypeMapper implements Serializable {
                 return String.valueOf(field);
             case DATE:
                 if (field instanceof LocalDate) {
-                    return Date.valueOf((LocalDate) field);
+                    return field;
                 }
                 return ((Date) field).toLocalDate();
             case TIME:
                 return ((Time) field).toLocalTime();
             case TIMESTAMP:
+                if (field instanceof Instant) {
+                    return ((Instant) field).atZone(ZoneId.systemDefault()).toLocalDateTime();
+                }
+                if (field instanceof ZonedDateTime) {
+                    return ((ZonedDateTime) field).toLocalDateTime();
+                }
+                if (field instanceof LocalDateTime) {
+                    return field;
+                }
                 return ((java.util.Date) field)
                         .toInstant()
                         .atZone(ZoneId.systemDefault())
