@@ -23,6 +23,7 @@ import org.apache.seatunnel.api.common.PrepareFailException;
 import org.apache.seatunnel.api.common.SeaTunnelAPIErrorCode;
 import org.apache.seatunnel.api.sink.SeaTunnelSink;
 import org.apache.seatunnel.api.sink.SinkWriter;
+import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.type.SeaTunnelRow;
 import org.apache.seatunnel.api.table.type.SeaTunnelRowType;
 import org.apache.seatunnel.common.constants.PluginType;
@@ -34,6 +35,7 @@ import org.apache.seatunnel.connectors.seatunnel.sentry.exception.SentryConnecto
 import com.google.auto.service.AutoService;
 
 import java.io.IOException;
+import java.util.Optional;
 
 /** @description: SentrySink class */
 @AutoService(SeaTunnelSink.class)
@@ -72,4 +74,9 @@ public class SentrySink extends AbstractSimpleSink<SeaTunnelRow, Void> {
             throws IOException {
         return new SentrySinkWriter(seaTunnelRowType, pluginConfig);
     }
+
+    @Override
+    public Optional<CatalogTable> getWriteCatalogTable() {
+        return super.getWriteCatalogTable();
+    }
 }
