@@ -25,9 +25,17 @@ import org.apache.seatunnel.engine.common.config.SeaTunnelConfig;
 import org.apache.seatunnel.engine.common.exception.SeaTunnelEngineException;
 import org.apache.seatunnel.engine.server.SeaTunnelServerStarter;
 
+import org.apache.commons.lang3.JavaVersion;
 import org.apache.commons.lang3.StringUtils;
+import org.apache.commons.lang3.SystemUtils;
+
+import lombok.extern.slf4j.Slf4j;
+
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 /** This command is used to execute the SeaTunnel engine job by SeaTunnel API. */
+@Slf4j
 public class ServerExecuteCommand implements Command<ServerCommandArgs> {
 
     private final ServerCommandArgs serverCommandArgs;
@@ -38,6 +46,7 @@ public class ServerExecuteCommand implements Command<ServerCommandArgs> {
 
     @Override
     public void execute() {
+        checkEnvironment();
         SeaTunnelConfig seaTunnelConfig = ConfigProvider.locateAndGetSeaTunnelConfig();
         String clusterRole = this.serverCommandArgs.getClusterRole();
         if (StringUtils.isNotBlank(clusterRole)) {
@@ -60,4 +69,32 @@ public class ServerExecuteCommand implements Command<ServerCommandArgs> {
         SeaTunnelServerStarter.createHazelcastInstance(
                 seaTunnelConfig, Thread.currentThread().getName());
     }
+
+    private void checkEnvironment() {
+        if (isAllocatingThreadGetName()) {
+            log.warn(
+                    "The current JDK version is not recommended. Please upgrade to JDK 1.8.0_102 or higher. "
+                            + "The current version will affect the performance of log printing. "
+                            + "For details, please refer to https://issues.apache.org/jira/browse/LOG4J2-2052");
+        }
+    }
+
+    static boolean isAllocatingThreadGetName() {
+        // LOG4J2-2052, LOG4J2-2635 JDK 8u102 ("1.8.0_102") removed the String allocation in
+        // Thread.getName()
+        if (SystemUtils.IS_JAVA_1_8) {
+            try {
+                Pattern javaVersionPattern = Pattern.compile("(\\d+)\\.(\\d+)\\.(\\d+)_(\\d+)");
+                Matcher m = javaVersionPattern.matcher(System.getProperty("java.version"));
+                if (m.matches()) {
+                    return Integer.parseInt(m.group(3)) == 0 && Integer.parseInt(m.group(4)) < 102;
+                }
+                return true;
+            } catch (Exception e) {
+                return true;
+            }
+        } else {
+            return !SystemUtils.isJavaVersionAtLeast(JavaVersion.JAVA_1_8);
+        }
+    }
 }
