@@ -16,102 +16,52 @@
  */
 package org.apache.seatunnel.connectors.seatunnel.cdc.oracle;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+
 import org.apache.seatunnel.e2e.common.TestResource;
-import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.ContainerExtendedFactory;
 import org.apache.seatunnel.e2e.common.container.EngineType;
 import org.apache.seatunnel.e2e.common.container.TestContainer;
 import org.apache.seatunnel.e2e.common.junit.DisabledOnContainer;
 import org.apache.seatunnel.e2e.common.junit.TestContainerExtension;
+import org.apache.seatunnel.e2e.common.util.JobIdGenerator;
 
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.TestTemplate;
 import org.testcontainers.containers.Container;
-import org.testcontainers.containers.output.Slf4jLogConsumer;
 import org.testcontainers.lifecycle.Startables;
-import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
-import java.net.URL;
-import java.nio.file.Files;
-import java.nio.file.Paths;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.List;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.TimeUnit;
-import java.util.regex.Matcher;
-import java.util.regex.Pattern;
-import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import static org.awaitility.Awaitility.await;
-import static org.junit.Assert.assertNotNull;
 
 @Slf4j
 @DisabledOnContainer(
         value = {},
         type = {EngineType.SPARK},
-        disabledReason =
-                "Currently SPARK do not support cdc,Flink is prone to time out, temporarily disable")
-public class OracleCDCIT extends TestSuiteBase implements TestResource {
+        disabledReason = "Currently SPARK do not support cdc")
+public class OracleCDCIT extends AbstractOracleCDCIT implements TestResource {
 
-    private static final String ORACLE_IMAGE = "goodboy008/oracle-19.3.0-ee:non-cdb";
-
-    private static final String HOST = "oracle-host";
-
-    private static final Integer ORACLE_PORT = 1521;
-
-    static {
-        System.setProperty("oracle.jdbc.timezoneAsRegion", "false");
-    }
-
-    public static final String CONNECTOR_USER = "dbzuser";
-
-    public static final String CONNECTOR_PWD = "dbz";
-
-    public static final String SCHEMA_USER = "debezium";
-
-    public static final String SCHEMA_PWD = "dbz";
-
-    public static final Pattern COMMENT_PATTERN = Pattern.compile("^(.*)--.*$");
-
-    private static final String DATABASE = "DEBEZIUM";
-    private static final String SOURCE_TABLE1 = "FULL_TYPES";
-    private static final String SOURCE_TABLE2 = "FULL_TYPES2";
     private static final String SOURCE_TABLE_NO_PRIMARY_KEY = "FULL_TYPES_NO_PRIMARY_KEY";
 
     private static final String SINK_TABLE1 = "SINK_FULL_TYPES";
     private static final String SINK_TABLE2 = "SINK_FULL_TYPES2";
-
     private static final String SOURCE_SQL_TEMPLATE = "select * from %s.%s ORDER BY ID";
 
-    public static final OracleContainer ORACLE_CONTAINER =
-            new OracleContainer(ORACLE_IMAGE)
-                    .withUsername(CONNECTOR_USER)
-                    .withPassword(CONNECTOR_PWD)
-                    .withDatabaseName("ORCLCDB")
-                    .withNetwork(NETWORK)
-                    .withNetworkAliases(HOST)
-                    .withExposedPorts(ORACLE_PORT)
-                    .withLogConsumer(
-                            new Slf4jLogConsumer(
-                                    DockerLoggerFactory.getLogger("oracle-docker-image")));
-
-    private String driverUrl() {
-        return "https://repo1.maven.org/maven2/com/oracle/database/jdbc/ojdbc8/12.2.0.1/ojdbc8-12.2.0.1.jar";
-    }
-
     @TestContainerExtension
     protected final ContainerExtendedFactory extendedFactory =
             container -> {
@@ -120,7 +70,7 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                 "bash",
                                 "-c",
                                 "mkdir -p /tmp/seatunnel/plugins/Oracle-CDC/lib && cd /tmp/seatunnel/plugins/Oracle-CDC/lib && wget "
-                                        + driverUrl());
+                                        + oracleDriverUrl());
                 Assertions.assertEquals(0, extraCommands.getExitCode(), extraCommands.getStderr());
             };
 
@@ -129,10 +79,58 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
     public void startUp() throws Exception {
         ORACLE_CONTAINER.setPortBindings(
                 Lists.newArrayList(String.format("%s:%s", ORACLE_PORT, ORACLE_PORT)));
-        log.info("Starting containers...");
+        log.info("Starting Oracle containers...");
         Startables.deepStart(Stream.of(ORACLE_CONTAINER)).join();
-        log.info("Containers are started.");
-        createAndInitialize(ORACLE_CONTAINER, "column_type_test");
+        log.info("Oracle containers are started.");
+        createAndInitialize("column_type_test", ADMIN_USER, ADMIN_PWD);
+    }
+
+    @AfterAll
+    @Override
+    public void tearDown() throws Exception {
+        ORACLE_CONTAINER.stop();
+    }
+
+    @TestTemplate
+    public void testOracleCdcPartition(TestContainer container) throws Exception {
+        String sourceTable = "PARTITION_SOURCE_TABLE";
+        String sinkTable = "PARTITION_SINK_TABLE";
+        clearTable(SCEHMA_NAME, sinkTable);
+        clearTable(SCEHMA_NAME, sourceTable);
+
+        insertSourceTable(SCEHMA_NAME, sourceTable);
+
+        CompletableFuture.supplyAsync(
+                () -> {
+                    try {
+                        container.executeJob("/oraclecdc_to_oracle_with_partition.conf");
+                    } catch (Exception e) {
+                        log.error("Commit task exception :" + e.getMessage());
+                        throw new RuntimeException(e);
+                    }
+                    return null;
+                });
+
+        // snapshot stage
+        await().atMost(600000, TimeUnit.MILLISECONDS)
+                .untilAsserted(
+                        () -> {
+                            Assertions.assertIterableEquals(
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, sourceTable)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, sinkTable)));
+                        });
+
+        // insert update delete
+        updateSourceTable(SCEHMA_NAME, sourceTable);
+
+        // stream stage
+        await().atMost(600000, TimeUnit.MILLISECONDS)
+                .untilAsserted(
+                        () -> {
+                            Assertions.assertIterableEquals(
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, sourceTable)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, sinkTable)));
+                        });
     }
 
     @TestTemplate
@@ -153,12 +151,12 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
 
     private void checkDataForTheJob(
             TestContainer container, String jobConfPath, Boolean skipAnalysis) throws Exception {
-        clearTable(DATABASE, SOURCE_TABLE1);
-        clearTable(DATABASE, SOURCE_TABLE2);
-        clearTable(DATABASE, SINK_TABLE1);
-        clearTable(DATABASE, SINK_TABLE2);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE2);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SINK_TABLE2);
 
-        insertSourceTable(DATABASE, SOURCE_TABLE1);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
 
         if (skipAnalysis) {
             // analyzeTable before execute job
@@ -168,7 +166,7 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                     + "\"DEBEZIUM\".\"FULL_TYPES\" "
                                     + "compute statistics for table");
             log.info("analyze table {}", analyzeTable);
-            try (Connection connection = testConnection(ORACLE_CONTAINER);
+            try (Connection connection = getJdbcConnection(ORACLE_CONTAINER);
                     Statement statement = connection.createStatement()) {
                 statement.execute(analyzeTable);
             }
@@ -190,30 +188,30 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                 .untilAsserted(
                         () -> {
                             Assertions.assertIterableEquals(
-                                    querySql(getSourceQuerySQL(DATABASE, SOURCE_TABLE1)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SOURCE_TABLE1)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
 
         // insert update delete
-        updateSourceTable(DATABASE, SOURCE_TABLE1);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
                 .untilAsserted(
                         () -> {
                             Assertions.assertIterableEquals(
-                                    querySql(getSourceQuerySQL(DATABASE, SOURCE_TABLE1)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SOURCE_TABLE1)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
     }
 
     @TestTemplate
     public void testOracleCdcCheckDataWithNoPrimaryKey(TestContainer container) throws Exception {
 
-        clearTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
-        clearTable(DATABASE, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
 
-        insertSourceTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
 
         CompletableFuture.supplyAsync(
                 () -> {
@@ -233,12 +231,12 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                             Assertions.assertIterableEquals(
                                     querySql(
                                             getSourceQuerySQL(
-                                                    DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                                    SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
 
         // insert update delete
-        updateSourceTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
@@ -247,8 +245,8 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                             Assertions.assertIterableEquals(
                                     querySql(
                                             getSourceQuerySQL(
-                                                    DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                                    SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
     }
 
@@ -256,10 +254,10 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
     public void testOracleCdcCheckDataWithCustomPrimaryKey(TestContainer container)
             throws Exception {
 
-        clearTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
-        clearTable(DATABASE, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
 
-        insertSourceTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
 
         CompletableFuture.supplyAsync(
                 () -> {
@@ -279,12 +277,12 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                             Assertions.assertIterableEquals(
                                     querySql(
                                             getSourceQuerySQL(
-                                                    DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                                    SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
 
         // insert update delete
-        updateSourceTable(DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
@@ -293,11 +291,53 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                             Assertions.assertIterableEquals(
                                     querySql(
                                             getSourceQuerySQL(
-                                                    DATABASE, SOURCE_TABLE_NO_PRIMARY_KEY)),
-                                    querySql(getSourceQuerySQL(DATABASE, SINK_TABLE1)));
+                                                    SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY)),
+                                    querySql(getSourceQuerySQL(SCEHMA_NAME, SINK_TABLE1)));
                         });
     }
 
+    @TestTemplate
+    @DisabledOnContainer(
+            value = {},
+            type = {EngineType.SPARK, EngineType.FLINK},
+            disabledReason =
+                    "This case requires obtaining the task health status and manually canceling the canceled task, which is currently only supported by the zeta engine.")
+    public void testOracleCdcMetadataTrans(TestContainer container) throws Exception {
+
+        clearTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
+
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
+        Long jobId = JobIdGenerator.newJobId();
+        CompletableFuture.supplyAsync(
+                () -> {
+                    try {
+                        container.executeJob(
+                                "/oraclecdc_to_metadata_trans.conf", String.valueOf(jobId));
+                    } catch (Exception e) {
+                        log.error("Commit task exception :" + e.getMessage());
+                        throw new RuntimeException(e);
+                    }
+                    return null;
+                });
+        TimeUnit.SECONDS.sleep(10);
+        // insert update delete
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE_NO_PRIMARY_KEY);
+        TimeUnit.SECONDS.sleep(20);
+        await().atMost(2, TimeUnit.MINUTES)
+                .untilAsserted(
+                        () -> {
+                            String jobStatus = container.getJobStatus(String.valueOf(jobId));
+                            Assertions.assertEquals("RUNNING", jobStatus);
+                        });
+        try {
+            Container.ExecResult cancelJobResult = container.cancelJob(String.valueOf(jobId));
+            Assertions.assertEquals(0, cancelJobResult.getExitCode(), cancelJobResult.getStderr());
+        } catch (IOException | InterruptedException e) {
+            throw new RuntimeException(e);
+        }
+    }
+
     @TestTemplate
     @DisabledOnContainer(
             value = {},
@@ -306,13 +346,13 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
     public void testOracleCdcMultiTableE2e(TestContainer container)
             throws IOException, InterruptedException {
 
-        clearTable(DATABASE, SOURCE_TABLE1);
-        clearTable(DATABASE, SOURCE_TABLE2);
-        clearTable(DATABASE, SINK_TABLE1);
-        clearTable(DATABASE, SINK_TABLE2);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE2);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SINK_TABLE2);
 
-        insertSourceTable(DATABASE, SOURCE_TABLE1);
-        insertSourceTable(DATABASE, SOURCE_TABLE2);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE2);
 
         CompletableFuture.supplyAsync(
                 () -> {
@@ -335,21 +375,24 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1))),
+                                                                        SCEHMA_NAME, SINK_TABLE1))),
                                         () ->
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE2)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE2)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE2)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE2)))));
 
-        updateSourceTable(DATABASE, SOURCE_TABLE1);
-        updateSourceTable(DATABASE, SOURCE_TABLE2);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE2);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
@@ -360,18 +403,21 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1))),
+                                                                        SCEHMA_NAME, SINK_TABLE1))),
                                         () ->
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE2)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE2)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE2)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE2)))));
     }
 
     @TestTemplate
@@ -382,19 +428,21 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
     public void testMultiTableWithRestore(TestContainer container)
             throws IOException, InterruptedException {
 
-        clearTable(DATABASE, SOURCE_TABLE1);
-        clearTable(DATABASE, SOURCE_TABLE2);
-        clearTable(DATABASE, SINK_TABLE1);
-        clearTable(DATABASE, SINK_TABLE2);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE2);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SINK_TABLE2);
 
-        insertSourceTable(DATABASE, SOURCE_TABLE1);
-        insertSourceTable(DATABASE, SOURCE_TABLE2);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
+        insertSourceTable(SCEHMA_NAME, SOURCE_TABLE2);
 
+        Long jobId = JobIdGenerator.newJobId();
         CompletableFuture.supplyAsync(
                 () -> {
                     try {
                         return container.executeJob(
-                                "/oraclecdc_to_oracle_with_multi_table_mode_one_table.conf");
+                                "/oraclecdc_to_oracle_with_multi_table_mode_one_table.conf",
+                                String.valueOf(jobId));
                     } catch (Exception e) {
                         log.error("Commit task exception :" + e.getMessage());
                         throw new RuntimeException(e);
@@ -410,13 +458,15 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE1)))));
 
         // insert update delete
-        updateSourceTable(DATABASE, SOURCE_TABLE1);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE1);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
@@ -427,31 +477,22 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE1)))));
 
-        Pattern jobIdPattern =
-                Pattern.compile(
-                        ".*Init JobMaster for Job oraclecdc_to_oracle_with_multi_table_mode_one_table.conf \\(([0-9]*)\\).*",
-                        Pattern.DOTALL);
-        Matcher matcher = jobIdPattern.matcher(container.getServerLogs());
-        String jobId;
-        if (matcher.matches()) {
-            jobId = matcher.group(1);
-        } else {
-            throw new RuntimeException("Can not find jobId");
-        }
-
-        Assertions.assertEquals(0, container.savepointJob(jobId).getExitCode());
+        Assertions.assertEquals(0, container.savepointJob(String.valueOf(jobId)).getExitCode());
 
         // Restore job with add a new table
         CompletableFuture.supplyAsync(
                 () -> {
                     try {
                         container.restoreJob(
-                                "/oraclecdc_to_oracle_with_multi_table_mode_two_table.conf", jobId);
+                                "/oraclecdc_to_oracle_with_multi_table_mode_two_table.conf",
+                                String.valueOf(jobId));
                     } catch (Exception e) {
                         log.error("Commit task exception :" + e.getMessage());
                         throw new RuntimeException(e);
@@ -468,20 +509,23 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1))),
+                                                                        SCEHMA_NAME, SINK_TABLE1))),
                                         () ->
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE2)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE2)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE2)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE2)))));
 
-        updateSourceTable(DATABASE, SOURCE_TABLE2);
+        updateSourceTable(SCEHMA_NAME, SOURCE_TABLE2);
 
         // stream stage
         await().atMost(600000, TimeUnit.MILLISECONDS)
@@ -492,18 +536,21 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE1)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE1)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE1))),
+                                                                        SCEHMA_NAME, SINK_TABLE1))),
                                         () ->
                                                 Assertions.assertIterableEquals(
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SOURCE_TABLE2)),
+                                                                        SCEHMA_NAME,
+                                                                        SOURCE_TABLE2)),
                                                         querySql(
                                                                 getSourceQuerySQL(
-                                                                        DATABASE, SINK_TABLE2)))));
+                                                                        SCEHMA_NAME,
+                                                                        SINK_TABLE2)))));
 
         log.info("****************** container logs start ******************");
         String containerLogs = container.getServerLogs();
@@ -511,43 +558,10 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
         Assertions.assertFalse(containerLogs.contains("ERROR"));
         log.info("****************** container logs end ******************");
 
-        clearTable(DATABASE, SOURCE_TABLE1);
-        clearTable(DATABASE, SOURCE_TABLE2);
-        clearTable(DATABASE, SINK_TABLE1);
-        clearTable(DATABASE, SINK_TABLE2);
-    }
-
-    public static void createAndInitialize(OracleContainer oracleContainer, String sqlFile)
-            throws Exception {
-        final String ddlFile = String.format("ddl/%s.sql", sqlFile);
-        final URL ddlTestFile = OracleCDCIT.class.getClassLoader().getResource(ddlFile);
-        assertNotNull("Cannot locate " + ddlFile, ddlTestFile);
-        try (Connection connection = testConnection(oracleContainer);
-                Statement statement = connection.createStatement()) {
-
-            final List<String> statements =
-                    Arrays.stream(
-                                    Files.readAllLines(Paths.get(ddlTestFile.toURI())).stream()
-                                            .map(String::trim)
-                                            .filter(x -> !x.startsWith("--") && !x.isEmpty())
-                                            .map(
-                                                    x -> {
-                                                        final Matcher m =
-                                                                COMMENT_PATTERN.matcher(x);
-                                                        return m.matches() ? m.group(1) : x;
-                                                    })
-                                            .collect(Collectors.joining("\n"))
-                                            .split(";"))
-                            .collect(Collectors.toList());
-
-            for (String stmt : statements) {
-                statement.execute(stmt);
-            }
-        }
-    }
-
-    public static Connection testConnection(OracleContainer oracleContainer) throws SQLException {
-        return DriverManager.getConnection(oracleContainer.getJdbcUrl(), SCHEMA_USER, SCHEMA_PWD);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE1);
+        clearTable(SCEHMA_NAME, SOURCE_TABLE2);
+        clearTable(SCEHMA_NAME, SINK_TABLE1);
+        clearTable(SCEHMA_NAME, SINK_TABLE2);
     }
 
     private List<List<Object>> querySql(String sql) {
@@ -607,7 +621,7 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                         + database
                         + "."
                         + tableName
-                        + " VALUES (1, 'vc2', 'vc2', 'nvc2', 'c', 'nc',1.1, 2.22, 3.33, 8.888, 4.4444, 5.555, 6.66, 1234.567891, 1234.567891, 77.323,1, 22, 333, 4444, 5555, 1, 99, 9999, 999999999, 999999999999999999,94, 9949, 999999994, 999999999999999949, 99999999999999999999999999999999999949,TO_DATE('2022-10-30', 'yyyy-mm-dd'),TO_TIMESTAMP('2022-10-30 12:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.125456789', 'yyyy-mm-dd HH24:MI:SS.FF9'),TO_TIMESTAMP_TZ('2022-10-30 01:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'))");
+                        + " VALUES (1, 'vc2', 'vc2', 'nvc2', 'c', 'nc',1.1, 2.22, 3.33, 8.888, 4.4444, 5.555, 6.66, 1234.567891, 1234.567891, 77.323,1, 22, 333, 4444, 5555, 1, 99, 1001, 999999999, 999999999999999999,94, 9949, 999999994, 999999999999999949, 99999999999999999999999999999999999949,TO_DATE('2022-10-30', 'yyyy-mm-dd'),TO_TIMESTAMP('2022-10-30 12:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.125456789', 'yyyy-mm-dd HH24:MI:SS.FF9'),TO_TIMESTAMP_TZ('2022-10-30 01:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'))");
     }
 
     private void updateSourceTable(String database, String tableName) {
@@ -616,7 +630,7 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
                         + database
                         + "."
                         + tableName
-                        + " VALUES (2, 'vc2', 'vc2', 'nvc2', 'c', 'nc',1.1, 2.22, 3.33, 8.888, 4.4444, 5.555, 6.66, 1234.567891, 1234.567891, 77.323,1, 22, 333, 4444, 5555, 1, 99, 9999, 999999999, 999999999999999999,94, 9949, 999999994, 999999999999999949, 99999999999999999999999999999999999949,TO_DATE('2022-10-30', 'yyyy-mm-dd'),TO_TIMESTAMP('2022-10-30 12:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.125456789', 'yyyy-mm-dd HH24:MI:SS.FF9'),TO_TIMESTAMP_TZ('2022-10-30 01:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'))");
+                        + " VALUES (2, 'vc2', 'vc2', 'nvc2', 'c', 'nc',1.1, 2.22, 3.33, 8.888, 4.4444, 5.555, 6.66, 1234.567891, 1234.567891, 77.323,1, 22, 333, 4444, 5555, 1, 99, 2001, 999999999, 999999999999999999,94, 9949, 999999994, 999999999999999949, 99999999999999999999999999999999999949,TO_DATE('2022-10-30', 'yyyy-mm-dd'),TO_TIMESTAMP('2022-10-30 12:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.12545', 'yyyy-mm-dd HH24:MI:SS.FF5'),TO_TIMESTAMP('2022-10-30 12:34:56.125456789', 'yyyy-mm-dd HH24:MI:SS.FF9'),TO_TIMESTAMP_TZ('2022-10-30 01:34:56.00789', 'yyyy-mm-dd HH24:MI:SS.FF5'))");
 
         executeSql(
                 "INSERT INTO "
@@ -645,10 +659,4 @@ public class OracleCDCIT extends TestSuiteBase implements TestResource {
     private void clearTable(String database, String tableName) {
         executeSql("truncate table " + database + "." + tableName, SCHEMA_USER, SCHEMA_PWD);
     }
-
-    @AfterAll
-    @Override
-    public void tearDown() throws Exception {
-        ORACLE_CONTAINER.stop();
-    }
 }
