@@ -269,3 +269,100 @@ create table DEBEZIUM.SINK_FULL_TYPES2 (
                                           primary key (ID)
 );
 
+CREATE TABLE DEBEZIUM.PARTITION_SOURCE_TABLE (
+                                     ID                           NUMBER(9) not null,
+                                     VAL_VARCHAR                  VARCHAR2(1000),
+                                     VAL_VARCHAR2                 VARCHAR2(1000),
+                                     VAL_NVARCHAR2                NVARCHAR2(1000),
+                                     VAL_CHAR                     CHAR(3),
+                                     VAL_NCHAR                    NCHAR(3),
+                                     VAL_BF                       BINARY_FLOAT,
+                                     VAL_BD                       BINARY_DOUBLE,
+                                     VAL_F                        FLOAT,
+                                     VAL_F_10                     FLOAT(10),
+                                     VAL_NUM                      NUMBER(10, 6),
+                                     VAL_DP                       FLOAT,
+                                     VAL_R                        FLOAT(63),
+                                     VAL_DECIMAL                  NUMBER(10, 6),
+                                     VAL_NUMERIC                  NUMBER(10, 6),
+                                     VAL_NUM_VS                   NUMBER,
+                                     VAL_INT                      NUMBER,
+                                     VAL_INTEGER                  NUMBER,
+                                     VAL_SMALLINT                 NUMBER,
+                                     VAL_NUMBER_38_NO_SCALE       NUMBER(38),
+                                     VAL_NUMBER_38_SCALE_0        NUMBER(38),
+                                     VAL_NUMBER_1                 NUMBER(1),
+                                     VAL_NUMBER_2                 NUMBER(2),
+                                     VAL_NUMBER_4                 NUMBER(4),
+                                     VAL_NUMBER_9                 NUMBER(9),
+                                     VAL_NUMBER_18                NUMBER(18),
+                                     VAL_NUMBER_2_NEGATIVE_SCALE  NUMBER(1, -1),
+                                     VAL_NUMBER_4_NEGATIVE_SCALE  NUMBER(2, -2),
+                                     VAL_NUMBER_9_NEGATIVE_SCALE  NUMBER(8, -1),
+                                     VAL_NUMBER_18_NEGATIVE_SCALE NUMBER(16, -2),
+                                     VAL_NUMBER_36_NEGATIVE_SCALE NUMBER(36, -2),
+                                     VAL_DATE                     DATE,
+                                     VAL_TS                       TIMESTAMP(6),
+                                     VAL_TS_PRECISION2            TIMESTAMP(2),
+                                     VAL_TS_PRECISION4            TIMESTAMP(4),
+                                     VAL_TS_PRECISION9            TIMESTAMP(6),
+                                     VAL_TSLTZ                    TIMESTAMP(6) WITH LOCAL TIME ZONE,
+                                     PRIMARY KEY (ID)
+)
+    PARTITION BY RANGE (VAL_NUMBER_4)
+(
+    PARTITION p1 VALUES LESS THAN (1000),
+    PARTITION p2 VALUES LESS THAN (2000),
+    PARTITION p3 VALUES LESS THAN (3000),
+    PARTITION p4 VALUES LESS THAN (MAXVALUE)
+);
+
+ALTER TABLE DEBEZIUM.PARTITION_SOURCE_TABLE ADD SUPPLEMENTAL LOG DATA (ALL) COLUMNS;
+
+CREATE TABLE DEBEZIUM.PARTITION_SINK_TABLE (
+                                          ID                           NUMBER(9) not null,
+                                          VAL_VARCHAR                  VARCHAR2(1000),
+                                          VAL_VARCHAR2                 VARCHAR2(1000),
+                                          VAL_NVARCHAR2                NVARCHAR2(1000),
+                                          VAL_CHAR                     CHAR(3),
+                                          VAL_NCHAR                    NCHAR(3),
+                                          VAL_BF                       BINARY_FLOAT,
+                                          VAL_BD                       BINARY_DOUBLE,
+                                          VAL_F                        FLOAT,
+                                          VAL_F_10                     FLOAT(10),
+                                          VAL_NUM                      NUMBER(10, 6),
+                                          VAL_DP                       FLOAT,
+                                          VAL_R                        FLOAT(63),
+                                          VAL_DECIMAL                  NUMBER(10, 6),
+                                          VAL_NUMERIC                  NUMBER(10, 6),
+                                          VAL_NUM_VS                   NUMBER,
+                                          VAL_INT                      NUMBER,
+                                          VAL_INTEGER                  NUMBER,
+                                          VAL_SMALLINT                 NUMBER,
+                                          VAL_NUMBER_38_NO_SCALE       NUMBER(38),
+                                          VAL_NUMBER_38_SCALE_0        NUMBER(38),
+                                          VAL_NUMBER_1                 NUMBER(1),
+                                          VAL_NUMBER_2                 NUMBER(2),
+                                          VAL_NUMBER_4                 NUMBER(4),
+                                          VAL_NUMBER_9                 NUMBER(9),
+                                          VAL_NUMBER_18                NUMBER(18),
+                                          VAL_NUMBER_2_NEGATIVE_SCALE  NUMBER(1, -1),
+                                          VAL_NUMBER_4_NEGATIVE_SCALE  NUMBER(2, -2),
+                                          VAL_NUMBER_9_NEGATIVE_SCALE  NUMBER(8, -1),
+                                          VAL_NUMBER_18_NEGATIVE_SCALE NUMBER(16, -2),
+                                          VAL_NUMBER_36_NEGATIVE_SCALE NUMBER(36, -2),
+                                          VAL_DATE                     DATE,
+                                          VAL_TS                       TIMESTAMP(6),
+                                          VAL_TS_PRECISION2            TIMESTAMP(2),
+                                          VAL_TS_PRECISION4            TIMESTAMP(4),
+                                          VAL_TS_PRECISION9            TIMESTAMP(6),
+                                          VAL_TSLTZ                    TIMESTAMP(6) WITH LOCAL TIME ZONE,
+                                          PRIMARY KEY (ID)
+)
+    PARTITION BY RANGE (VAL_NUMBER_4)
+(
+    PARTITION p1 VALUES LESS THAN (1000),
+    PARTITION p2 VALUES LESS THAN (2000),
+    PARTITION p3 VALUES LESS THAN (3000),
+    PARTITION p4 VALUES LESS THAN (MAXVALUE)
+);
\ No newline at end of file
