@@ -202,6 +202,16 @@ public class DorisIT extends AbstractDorisIT {
         checkAllTypeSinkData();
     }
 
+    @TestTemplate
+    public void testNoSchemaDoris(TestContainer container)
+            throws IOException, InterruptedException {
+        initializeJdbcTable();
+        batchInsertUniqueTableData();
+        Container.ExecResult execResult1 = container.executeJob("/doris_source_no_schema.conf");
+        Assertions.assertEquals(0, execResult1.getExitCode());
+        checkSinkData();
+    }
+
     private void checkAllTypeSinkData() {
         try {
             assertHasData(sourceDB, DUPLICATE_TABLE);
@@ -412,6 +422,7 @@ public class DorisIT extends AbstractDorisIT {
                 // create source and sink table
                 statement.execute(createUniqueTableForTest(sourceDB));
                 statement.execute(createDuplicateTableForTest(sourceDB));
+                log.info("create source and sink table succeed");
             } catch (SQLException e) {
                 throw new RuntimeException("Initializing table failed!", e);
             }
@@ -738,7 +749,7 @@ public class DorisIT extends AbstractDorisIT {
     }
 
     public void getErrorUrl(String message) {
-        // 使用正则表达式匹配URL
+        // Using regular expressions to match URLs
         Pattern pattern = Pattern.compile("http://[\\w./?=&-_]+");
         Matcher matcher = pattern.matcher(message);
         String urlString = null;
@@ -754,12 +765,12 @@ public class DorisIT extends AbstractDorisIT {
             URL url = new URL(urlString);
             HttpURLConnection connection = (HttpURLConnection) url.openConnection();
 
-            // 设置请求方法
+            // Set the request method
             connection.setRequestMethod("GET");
 
-            // 设置连接超时时间
+            // Set the connection timeout
             connection.setConnectTimeout(5000);
-            // 设置读取超时时间
+            // Set the read timeout
             connection.setReadTimeout(5000);
 
             int responseCode = connection.getResponseCode();
