@@ -133,6 +133,9 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         createIndexDocs();
         createIndexWithFullType();
         createIndexForResourceNull("st_index4");
+        createIndexWithNestType();
+        createIndexForSqlSearch();
+        generateTestSqlDataSet();
     }
 
     /** create a index,and bulk some documents */
@@ -144,6 +147,92 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         createIndexDocsByName(indexName, testDataset1);
     }
 
+    private void createIndexForSqlSearch() throws IOException {
+        String mapping =
+                IOUtils.toString(
+                        ContainerUtil.getResourcesFile("/elasticsearch/st_index_with_sql.json")
+                                .toURI(),
+                        StandardCharsets.UTF_8);
+        esRestClient.createIndex("st_index_sql", mapping);
+    }
+
+    private void generateTestSqlDataSet() throws JsonProcessingException, InterruptedException {
+        String[] fields =
+                new String[] {
+                    "c_string",
+                    "c_boolean",
+                    "c_tinyint",
+                    "c_smallint",
+                    "c_bigint",
+                    "c_float",
+                    "c_double",
+                    "c_decimal",
+                    "c_bytes",
+                    "c_int",
+                    "c_date",
+                    "c_timestamp"
+                };
+
+        List<String> documents = new ArrayList<>();
+        ObjectMapper objectMapper = new ObjectMapper();
+        Map<String, Object> doc1 = new HashMap<>();
+        Object[] values1 =
+                new Object[] {
+                    "string",
+                    Boolean.FALSE,
+                    Byte.parseByte("1"),
+                    Short.parseShort("1"),
+                    Long.parseLong("1"),
+                    Float.parseFloat("1.1"),
+                    Double.parseDouble("1.1"),
+                    BigDecimal.valueOf(11, 1),
+                    "test".getBytes(),
+                    10,
+                    "2025-03-03T00:00:00.000Z",
+                    1740969505487L
+                };
+        for (int j = 0; j < fields.length; j++) {
+            doc1.put(fields[j], values1[j]);
+        }
+        documents.add(objectMapper.writeValueAsString(doc1));
+
+        Map<String, Object> doc2 = new HashMap<>();
+        Object[] values2 =
+                new Object[] {
+                    "string",
+                    Boolean.FALSE,
+                    Byte.parseByte("1"),
+                    Short.parseShort("1"),
+                    Long.parseLong("1"),
+                    Float.parseFloat("1.1"),
+                    Double.parseDouble("1.1"),
+                    BigDecimal.valueOf(11, 1),
+                    "test".getBytes(),
+                    30,
+                    "2025-03-03T00:00:00.000Z",
+                    1740969505487L
+                };
+        for (int j = 0; j < fields.length; j++) {
+            doc2.put(fields[j], values2[j]);
+        }
+        documents.add(objectMapper.writeValueAsString(doc2));
+
+        StringBuilder requestBody = new StringBuilder();
+        String indexHeader = String.format("{\"index\":{\"_index\":\"%s\"}\n", "st_index_sql");
+        for (int i = 0; i < documents.size(); i++) {
+            String row = documents.get(i);
+            requestBody.append(indexHeader);
+            requestBody.append(row);
+            requestBody.append("\n");
+        }
+        BulkResponse response = esRestClient.bulk(requestBody.toString());
+        Assertions.assertFalse(response.isErrors(), response.getResponse());
+        // waiting index refresh
+        Thread.sleep(INDEX_REFRESH_MILL_DELAY);
+        Assertions.assertEquals(
+                2, esRestClient.getIndexDocsCount("st_index_sql").get(0).getDocsCount());
+    }
+
     private void createIndexDocsByName(String indexName, List<String> testDataSet) {
         StringBuilder requestBody = new StringBuilder();
         String indexHeader = String.format("{\"index\":{\"_index\":\"%s\"}\n", indexName);
@@ -156,6 +245,31 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         esRestClient.bulk(requestBody.toString());
     }
 
+    private void createIndexWithNestType() throws IOException, InterruptedException {
+        String mapping =
+                IOUtils.toString(
+                        ContainerUtil.getResourcesFile("/elasticsearch/st_index_nest_mapping.json")
+                                .toURI(),
+                        StandardCharsets.UTF_8);
+        esRestClient.createIndex("st_index_nest", mapping);
+        esRestClient.createIndex("st_index_nest_copy", mapping);
+        BulkResponse response =
+                esRestClient.bulk(
+                        "{ \"index\" : { \"_index\" : \"st_index_nest\", \"_id\" : \"1\" } }\n"
+                                + IOUtils.toString(
+                                                ContainerUtil.getResourcesFile(
+                                                                "/elasticsearch/st_index_nest_data.json")
+                                                        .toURI(),
+                                                StandardCharsets.UTF_8)
+                                        .replace("\n", "")
+                                + "\n");
+        Assertions.assertFalse(response.isErrors(), response.getResponse());
+        // waiting index refresh
+        Thread.sleep(INDEX_REFRESH_MILL_DELAY);
+        Assertions.assertEquals(
+                3, esRestClient.getIndexDocsCount("st_index_nest").get(0).getDocsCount());
+    }
+
     private void createIndexWithFullType() throws IOException, InterruptedException {
         String mapping =
                 IOUtils.toString(
@@ -202,6 +316,29 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         Assertions.assertIterableEquals(mapTestDatasetForDSL(), sinkData);
     }
 
+    @TestTemplate
+    public void testElasticsearchWithNestSchema(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/elasticsearch/elasticsearch_source_and_sink_with_nest.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+
+        List<String> sinkData = readSinkDataWithNestSchema("st_index_nest_copy");
+        String data =
+                "{\"address\":[{\"zipcode\":\"10001\",\"city\":\"New York\",\"street\":\"123 Main St\"},"
+                        + "{\"zipcode\":\"90001\",\"city\":\"Los Angeles\",\"street\":\"456 Elm St\"}],\"name\":\"John Doe\"}";
+
+        Assertions.assertIterableEquals(Lists.newArrayList(data), sinkData);
+    }
+
+    @TestTemplate
+    public void testElasticsearchWithSql(TestContainer container)
+            throws IOException, InterruptedException {
+        Container.ExecResult execResult =
+                container.executeJob("/elasticsearch/elasticsearch_source_with_sql.conf");
+        Assertions.assertEquals(0, execResult.getExitCode());
+    }
+
     @TestTemplate
     public void testElasticsSearchWithMultiSourceByFilter(TestContainer container)
             throws InterruptedException, IOException {
@@ -546,6 +683,13 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         return getDocsWithTransformTimestamp(source, index);
     }
 
+    private List<String> readSinkDataWithNestSchema(String index) throws InterruptedException {
+        // wait for index refresh
+        Thread.sleep(INDEX_REFRESH_MILL_DELAY);
+        List<String> source = Lists.newArrayList("name", "address");
+        return getDocsWithNestType(source, index);
+    }
+
     private List<String> readMultiSinkData(String index, List<String> source)
             throws InterruptedException {
         // wait for index refresh
@@ -604,6 +748,25 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
         return docs;
     }
 
+    private List<String> getDocsWithNestType(List<String> source, String index) {
+        Map<String, Object> query = new HashMap<>();
+        query.put("match_all", new HashMap<>());
+        ScrollResult scrollResult = esRestClient.searchByScroll(index, source, query, "1m", 1000);
+        scrollResult
+                .getDocs()
+                .forEach(
+                        x -> {
+                            x.remove("_index");
+                            x.remove("_type");
+                            x.remove("_id");
+                        });
+        List<String> docs =
+                scrollResult.getDocs().stream()
+                        .map(JsonUtils::toJsonString)
+                        .collect(Collectors.toList());
+        return docs;
+    }
+
     private List<String> getDocsWithTransformDate(List<String> source, String index) {
         return getDocsWithTransformDate(source, index, Collections.emptyList());
     }
@@ -739,6 +902,13 @@ public class ElasticsearchIT extends TestSuiteBase implements TestResource {
                 .collect(Collectors.toList());
     }
 
+    private List<String> mapTestDatasetForNest(List<String> testDataset) {
+        return testDataset.stream()
+                .map(JsonUtils::parseObject)
+                .map(JsonNode::toString)
+                .collect(Collectors.toList());
+    }
+
     /**
      * Use custom filtering criteria to query data
      *
