@@ -286,6 +286,11 @@ public class LocalFileIT extends TestSuiteBase {
                         "/seatunnel/read/excel_filter/name=tyrantlucifer/hobby=coding/e2e_filter.xlsx",
                         container);
 
+                ContainerUtil.copyFileIntoContainers(
+                        "/csv/break_line.csv",
+                        "/seatunnel/read/csv/break_line/break_line.csv",
+                        container);
+
                 ContainerUtil.copyFileIntoContainers(
                         "/text/e2e_null_format.txt",
                         "/seatunnel/read/e2e_null_format/e2e_null_format.txt",
@@ -298,6 +303,9 @@ public class LocalFileIT extends TestSuiteBase {
     public void testLocalFileReadAndWrite(TestContainer container)
             throws IOException, InterruptedException {
         TestHelper helper = new TestHelper(container);
+        helper.execute("/csv/fake_to_local_csv.conf");
+        helper.execute("/csv/local_csv_to_assert.conf");
+        helper.execute("/csv/breakline_csv_to_assert.conf");
         helper.execute("/excel/fake_to_local_excel.conf");
         helper.execute("/excel/local_excel_to_assert.conf");
         helper.execute("/excel/local_excel_projection_to_assert.conf");
