@@ -23,8 +23,9 @@ import org.apache.seatunnel.api.table.catalog.TablePath;
 import org.apache.seatunnel.api.table.catalog.exception.TableAlreadyExistException;
 import org.apache.seatunnel.api.table.catalog.exception.TableNotExistException;
 import org.apache.seatunnel.connectors.seatunnel.hbase.catalog.HbaseCatalog;
-import org.apache.seatunnel.connectors.seatunnel.hbase.config.HbaseConfig;
+import org.apache.seatunnel.connectors.seatunnel.hbase.config.HbaseBaseOptions;
 import org.apache.seatunnel.connectors.seatunnel.hbase.config.HbaseParameters;
+import org.apache.seatunnel.connectors.seatunnel.hbase.config.HbaseSinkOptions;
 import org.apache.seatunnel.e2e.common.TestResource;
 import org.apache.seatunnel.e2e.common.TestSuiteBase;
 import org.apache.seatunnel.e2e.common.container.EngineType;
@@ -109,10 +110,10 @@ public class HbaseIT extends TestSuiteBase implements TestResource {
         hbaseCluster.createTable(MULTI_TABLE_TWO_NAME, Arrays.asList(FAMILY_NAME));
 
         Map<String, Object> config = new HashMap<>();
-        config.put(HbaseConfig.ZOOKEEPER_QUORUM.key(), hbaseCluster.getZookeeperQuorum());
-        config.put(HbaseConfig.ROWKEY_COLUMNS.key(), "id");
-        config.put(HbaseConfig.FAMILY_NAME.key(), Maps.of("all_columns", FAMILY_NAME));
-        config.put(HbaseConfig.TABLE.key(), TABLE_NAME);
+        config.put(HbaseBaseOptions.ZOOKEEPER_QUORUM.key(), hbaseCluster.getZookeeperQuorum());
+        config.put(HbaseBaseOptions.ROWKEY_COLUMNS.key(), "id");
+        config.put(HbaseSinkOptions.FAMILY_NAME.key(), Maps.of("all_columns", FAMILY_NAME));
+        config.put(HbaseBaseOptions.TABLE.key(), TABLE_NAME);
         // config.put(HbaseConfig.)
 
         catalog =
