@@ -47,9 +47,12 @@ import org.testcontainers.utility.DockerLoggerFactory;
 
 import lombok.extern.slf4j.Slf4j;
 
+import java.io.BufferedReader;
 import java.io.IOException;
+import java.io.Reader;
 import java.sql.Connection;
 import java.sql.DriverManager;
+import java.sql.NClob;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.time.Duration;
@@ -101,6 +104,10 @@ public abstract class AbstractSchemaChangeBaseIT extends TestSuiteBase implement
 
     protected abstract GenericContainer initSinkContainer();
 
+    protected abstract String sinkDatabaseType();
+
+    protected void intializeSinkDatabase() {}
+
     @BeforeAll
     @Override
     public void startUp() {
@@ -110,11 +117,12 @@ public abstract class AbstractSchemaChangeBaseIT extends TestSuiteBase implement
         log.info("Mysql Containers are started");
         sourceDatabase.createAndInitialize();
         log.info("Mysql ddl execution is complete");
-
-        log.info("The third stage: Starting {} containers...", schemaChangeCase.getDbType());
+        // sink database initialization
+        log.info("The third stage: Starting {} containers...", sinkDatabaseType());
         sinkDbServer = initSinkContainer().withImagePullPolicy(PullPolicy.defaultPolicy());
         Startables.deepStart(Stream.of(sinkDbServer)).join();
-        log.info("{} Containers are started", schemaChangeCase.getDbType());
+        log.info("{} Containers are started", sinkDatabaseType());
+        intializeSinkDatabase();
     }
 
     @AfterAll
@@ -255,7 +263,7 @@ public abstract class AbstractSchemaChangeBaseIT extends TestSuiteBase implement
         if (!schemaChangeCase.isOpenExactlyOnce()) {
             log.info(
                     "{} not support Xa transactions, Skip testMysqlCdcWithSchemaEvolutionCaseExactlyOnce",
-                    schemaChangeCase.getDbType());
+                    sinkDatabaseType());
             return;
         }
         String jobConfigFile = schemaChangeCase.getSchemaEvolutionCaseExactlyOnce();
@@ -492,12 +500,17 @@ public abstract class AbstractSchemaChangeBaseIT extends TestSuiteBase implement
             while (resultSet.next()) {
                 ArrayList<Object> objects = new ArrayList<>();
                 for (int i = 1; i <= columnCount; i++) {
-                    objects.add(resultSet.getObject(i));
+                    Object object = resultSet.getObject(i);
+                    if (object instanceof NClob) {
+                        objects.add(readNClobAsString((NClob) object));
+                    } else {
+                        objects.add(object);
+                    }
                 }
                 log.debug(
                         String.format(
                                 "Print %s query, sql: %s, data: %s",
-                                schemaChangeCase.getDbType(), sql, objects));
+                                sinkDatabaseType(), sql, objects));
                 result.add(objects);
             }
             return result;
@@ -505,4 +518,18 @@ public abstract class AbstractSchemaChangeBaseIT extends TestSuiteBase implement
             throw new RuntimeException(e);
         }
     }
+
+    private Object readNClobAsString(NClob nclob) {
+        try (Reader reader = nclob.getCharacterStream();
+                BufferedReader bufferedReader = new BufferedReader(reader)) {
+            StringBuilder stringBuilder = new StringBuilder();
+            String line;
+            while ((line = bufferedReader.readLine()) != null) {
+                stringBuilder.append(line);
+            }
+            return stringBuilder.toString();
+        } catch (SQLException | IOException e) {
+            throw new RuntimeException(e);
+        }
+    }
 }
