@@ -17,6 +17,8 @@
 
 package org.apache.seatunnel.connectors.seatunnel.jdbc;
 
+import org.apache.seatunnel.shade.com.google.common.collect.Lists;
+
 import org.apache.seatunnel.api.table.catalog.Catalog;
 import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.catalog.ConstraintKey;
@@ -46,7 +48,6 @@ import org.testcontainers.lifecycle.Startables;
 import org.testcontainers.utility.DockerImageName;
 import org.testcontainers.utility.DockerLoggerFactory;
 
-import com.google.common.collect.Lists;
 import lombok.extern.slf4j.Slf4j;
 
 import java.io.IOException;
@@ -85,6 +86,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                     + "  uuid_col UUID,\n"
                     + "  text_col TEXT,\n"
                     + "  varchar_col VARCHAR(255),\n"
+                    + "  char_one_col CHAR(1),\n"
                     + "  char_col CHAR(10),\n"
                     + "  boolean_col bool,\n"
                     + "  smallint_col int2,\n"
@@ -120,6 +122,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                     + "    uuid_col UUID,\n"
                     + "    text_col TEXT,\n"
                     + "    varchar_col VARCHAR(255),\n"
+                    + "    char_one_col CHAR(1),\n"
                     + "    char_col CHAR(10),\n"
                     + "    boolean_col bool,\n"
                     + "    smallint_col int2,\n"
@@ -155,6 +158,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                     + "uuid_col, \n"
                     + "text_col,\n"
                     + "varchar_col,\n"
+                    + "char_one_col,\n"
                     + "char_col,\n"
                     + "boolean_col,\n"
                     + "smallint_col,\n"
@@ -190,6 +194,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                     + "uuid_col, \n"
                     + "   text_col,\n"
                     + "   varchar_col,\n"
+                    + "   char_one_col,\n"
                     + "   char_col,\n"
                     + "   boolean_col,\n"
                     + "   smallint_col,\n"
@@ -391,6 +396,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                                 + "    uuid_col,\n"
                                 + "    text_col,\n"
                                 + "    varchar_col,\n"
+                                + "    char_one_col,\n"
                                 + "    char_col,\n"
                                 + "    boolean_col,\n"
                                 + "    smallint_col,\n"
@@ -428,6 +434,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                                 + "    gen_random_uuid(),\n"
                                 + "    'Hello World',\n"
                                 + "    'Test',\n"
+                                + "    'T',\n"
                                 + "    'Testing',\n"
                                 + "    true,\n"
                                 + "    10,\n"
@@ -561,6 +568,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                         + "  pg_ide_sink_table_2 (gid,\n"
                         + "    text_col,\n"
                         + "    varchar_col,\n"
+                        + "    char_one_col,\n"
                         + "    char_col,\n"
                         + "    boolean_col,\n"
                         + "    smallint_col,\n"
@@ -597,6 +605,7 @@ public class JdbcPostgresIT extends TestSuiteBase implements TestResource {
                         + "',\n"
                         + "    'Hello World',\n"
                         + "    'Test',\n"
+                        + "    'T',\n"
                         + "    'Testing',\n"
                         + "    true,\n"
                         + "    10,\n"
