@@ -62,6 +62,9 @@ import org.apache.kafka.clients.producer.ProducerConfig;
 import org.apache.kafka.clients.producer.ProducerRecord;
 import org.apache.kafka.common.IsolationLevel;
 import org.apache.kafka.common.TopicPartition;
+import org.apache.kafka.common.header.Header;
+import org.apache.kafka.common.header.Headers;
+import org.apache.kafka.common.header.internals.RecordHeader;
 import org.apache.kafka.common.serialization.ByteArrayDeserializer;
 import org.apache.kafka.common.serialization.ByteArraySerializer;
 import org.apache.kafka.common.serialization.StringDeserializer;
@@ -86,6 +89,7 @@ import java.io.IOException;
 import java.math.BigDecimal;
 import java.net.URISyntaxException;
 import java.net.URL;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Paths;
 import java.time.Duration;
 import java.time.LocalDate;
@@ -119,6 +123,8 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
 
     private KafkaContainer kafkaContainer;
 
+    private List<ConsumerRecord<String, String>> nativeData;
+
     @BeforeAll
     @Override
     public void startUp() throws Exception {
@@ -146,6 +152,9 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         DEFAULT_FIELD_DELIMITER,
                         null);
         generateTestData(serializer::serializeRow, 0, 100);
+        String topicName = "test_topic_native_source";
+        generateNativeTestData("test_topic_native_source", 0, 100);
+        nativeData = getKafkaRecordData(topicName);
     }
 
     @AfterAll
@@ -174,6 +183,39 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(10, data.size());
     }
 
+    @TestTemplate
+    public void testNativeSinkKafka(TestContainer container)
+            throws IOException, InterruptedException {
+        String topicNativeName = "test_topic_native_sink";
+
+        Container.ExecResult execResultNative = container.executeJob("/kafka_native_to_kafka.conf");
+        Assertions.assertEquals(0, execResultNative.getExitCode(), execResultNative.getStderr());
+
+        List<ConsumerRecord<String, String>> dataNative = getKafkaRecordData(topicNativeName);
+
+        Assertions.assertEquals(dataNative.size(), nativeData.size());
+
+        for (int i = 0; i < nativeData.size(); i++) {
+            ConsumerRecord<String, String> oldRecord = nativeData.get(i);
+            ConsumerRecord<String, String> newRecord = dataNative.get(i);
+            Assertions.assertEquals(oldRecord.key(), newRecord.key());
+            Assertions.assertEquals(
+                    convertHeadersToMap(oldRecord.headers()),
+                    convertHeadersToMap(newRecord.headers()));
+            Assertions.assertEquals(oldRecord.partition(), newRecord.partition());
+            Assertions.assertEquals(oldRecord.timestamp(), newRecord.timestamp());
+            Assertions.assertEquals(oldRecord.value(), newRecord.value());
+        }
+    }
+
+    private Map<String, String> convertHeadersToMap(Headers headers) {
+        Map<String, String> map = new HashMap<>();
+        for (Header header : headers) {
+            map.put(header.key(), new String(header.value(), StandardCharsets.UTF_8));
+        }
+        return map;
+    }
+
     @TestTemplate
     public void testTextFormatSinkKafka(TestContainer container)
             throws IOException, InterruptedException {
@@ -231,6 +273,26 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
     }
 
+    @TestTemplate
+    public void testTextFormatWithNoSchema(TestContainer container)
+            throws IOException, InterruptedException {
+        try {
+            for (int i = 0; i < 100; i++) {
+                ProducerRecord<byte[], byte[]> producerRecord =
+                        new ProducerRecord<>(
+                                "test_topic_text_no_schema", null, "abcdef".getBytes());
+                producer.send(producerRecord).get();
+            }
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        } finally {
+            producer.flush();
+        }
+        Container.ExecResult execResult =
+                container.executeJob("/textFormatIT/kafka_source_text_with_no_schema.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+    }
+
     @TestTemplate
     public void testSourceKafkaToAssertWithMaxPollRecords1(TestContainer container)
             throws IOException, InterruptedException {
@@ -269,6 +331,26 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
     }
 
+    @TestTemplate
+    public void testSourceKafkaTopicWithMultipleDotConsoleAssertCatalogTable(
+            TestContainer container) throws IOException, InterruptedException {
+        TextSerializationSchema serializer =
+                TextSerializationSchema.builder()
+                        .seaTunnelRowType(SEATUNNEL_ROW_TYPE)
+                        .delimiter(",")
+                        .build();
+        generateTestData(
+                row ->
+                        new ProducerRecord<>(
+                                "test.multiple.point.topic.json", null, serializer.serialize(row)),
+                0,
+                10);
+        Container.ExecResult execResult =
+                container.executeJob(
+                        "/textFormatIT/kafka_source_topic_multiple_point_text_to_console.conf");
+        Assertions.assertEquals(0, execResult.getExitCode(), execResult.getStderr());
+    }
+
     @TestTemplate
     public void testSourceKafkaJsonToConsole(TestContainer container)
             throws IOException, InterruptedException {
@@ -295,7 +377,7 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
                         DEFAULT_FORMAT,
                         DEFAULT_FIELD_DELIMITER,
                         null);
-        generateTestData(serializer::serializeRow, 0, 100);
+        generateTestData(serializer::serializeRow, 0, 10);
         Container.ExecResult execResult =
                 container.executeJob(
                         "/kafka/kafkasource_format_error_handle_way_skip_to_console.conf");
@@ -1081,6 +1163,29 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         producer.flush();
     }
 
+    private void generateNativeTestData(String topic, int start, int end) {
+        try {
+            for (int i = start; i < end; i++) {
+                Integer partition = 0;
+                Long timestamp = System.currentTimeMillis();
+                byte[] key = ("native-key" + i).getBytes(StandardCharsets.UTF_8);
+                byte[] value = ("native-value" + i).getBytes(StandardCharsets.UTF_8);
+
+                Header header1 =
+                        new RecordHeader("header1", "value1".getBytes(StandardCharsets.UTF_8));
+                Header header2 =
+                        new RecordHeader("header2", "value2".getBytes(StandardCharsets.UTF_8));
+                List<Header> headers = Arrays.asList(header1, header2);
+                ProducerRecord<byte[], byte[]> record =
+                        new ProducerRecord<>(topic, partition, timestamp, key, value, headers);
+                producer.send(record).get();
+            }
+        } catch (Exception e) {
+            throw new RuntimeException(e);
+        }
+        producer.flush();
+    }
+
     private static final SeaTunnelRowType SEATUNNEL_ROW_TYPE =
             new SeaTunnelRowType(
                     new String[] {
@@ -1140,6 +1245,28 @@ public class KafkaIT extends TestSuiteBase implements TestResource {
         return data;
     }
 
+    private List<ConsumerRecord<String, String>> getKafkaRecordData(String topicName) {
+        List<ConsumerRecord<String, String>> data = new ArrayList<>();
+        try (KafkaConsumer<String, String> consumer = new KafkaConsumer<>(kafkaConsumerConfig())) {
+            consumer.subscribe(Arrays.asList(topicName));
+            Map<TopicPartition, Long> offsets =
+                    consumer.endOffsets(Arrays.asList(new TopicPartition(topicName, 0)));
+            Long endOffset = offsets.entrySet().iterator().next().getValue();
+            Long lastProcessedOffset = -1L;
+
+            do {
+                ConsumerRecords<String, String> records = consumer.poll(Duration.ofMillis(100));
+                for (ConsumerRecord<String, String> record : records) {
+                    if (lastProcessedOffset < record.offset()) {
+                        data.add(record);
+                    }
+                    lastProcessedOffset = record.offset();
+                }
+            } while (lastProcessedOffset < endOffset - 1);
+        }
+        return data;
+    }
+
     private List<String> getKafkaConsumerListData(String topicName) {
         List<String> data = new ArrayList<>();
         try (KafkaConsumer<String, String> consumer = new KafkaConsumer<>(kafkaConsumerConfig())) {
