@@ -17,6 +17,7 @@
 
 package org.apache.seatunnel.engine.common.config;
 
+import org.apache.seatunnel.engine.common.config.server.AllocateStrategy;
 import org.apache.seatunnel.engine.common.config.server.CheckpointConfig;
 import org.apache.seatunnel.engine.common.config.server.CheckpointStorageConfig;
 import org.apache.seatunnel.engine.common.config.server.ConnectorJarHAStorageConfig;
@@ -95,11 +96,18 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         SlotServiceConfig slotServiceConfig = new SlotServiceConfig();
         for (Node node : childElements(slotServiceNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.DYNAMIC_SLOT.key().equals(name)) {
+            if (ServerConfigOptions.WorkerServerConfigOptions.DYNAMIC_SLOT.key().equals(name)) {
                 slotServiceConfig.setDynamicSlot(getBooleanValue(getTextContent(node)));
-            } else if (ServerConfigOptions.SLOT_NUM.key().equals(name)) {
+            } else if (ServerConfigOptions.WorkerServerConfigOptions.SLOT_NUM.key().equals(name)) {
                 slotServiceConfig.setSlotNum(
-                        getIntegerValue(ServerConfigOptions.SLOT_NUM.key(), getTextContent(node)));
+                        getIntegerValue(
+                                ServerConfigOptions.WorkerServerConfigOptions.SLOT_NUM.key(),
+                                getTextContent(node)));
+            } else if (ServerConfigOptions.MasterServerConfigOptions.SLOT_ALLOCATE_STRATEGY
+                    .key()
+                    .equals(name)) {
+                slotServiceConfig.setAllocateStrategy(
+                        AllocateStrategy.valueOf(getTextContent(node).toUpperCase()));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
             }
@@ -111,14 +119,18 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         CoordinatorServiceConfig coordinatorServiceConfig = new CoordinatorServiceConfig();
         for (Node node : childElements(coordinatorServiceNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.MAX_THREAD_NUM.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.MAX_THREAD_NUM.key().equals(name)) {
                 coordinatorServiceConfig.setMaxThreadNum(
                         getIntegerValue(
-                                ServerConfigOptions.MAX_THREAD_NUM.key(), getTextContent(node)));
-            } else if (ServerConfigOptions.CORE_THREAD_NUM.key().equals(name)) {
+                                ServerConfigOptions.MasterServerConfigOptions.MAX_THREAD_NUM.key(),
+                                getTextContent(node)));
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CORE_THREAD_NUM
+                    .key()
+                    .equals(name)) {
                 coordinatorServiceConfig.setCoreThreadNum(
                         getIntegerValue(
-                                ServerConfigOptions.CORE_THREAD_NUM.key(), getTextContent(node)));
+                                ServerConfigOptions.MasterServerConfigOptions.CORE_THREAD_NUM.key(),
+                                getTextContent(node)));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
             }
@@ -130,56 +142,91 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         final EngineConfig engineConfig = config.getEngineConfig();
         for (Node node : childElements(engineNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.BACKUP_COUNT.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.BACKUP_COUNT.key().equals(name)) {
                 engineConfig.setBackupCount(
                         getIntegerValue(
-                                ServerConfigOptions.BACKUP_COUNT.key(), getTextContent(node)));
-            } else if (ServerConfigOptions.QUEUE_TYPE.key().equals(name)) {
+                                ServerConfigOptions.MasterServerConfigOptions.BACKUP_COUNT.key(),
+                                getTextContent(node)));
+            } else if (ServerConfigOptions.WorkerServerConfigOptions.QUEUE_TYPE
+                    .key()
+                    .equals(name)) {
                 engineConfig.setQueueType(
                         QueueType.valueOf(getTextContent(node).toUpperCase(Locale.ROOT)));
-            } else if (ServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL
+                    .key()
+                    .equals(name)) {
                 engineConfig.setPrintExecutionInfoInterval(
                         getIntegerValue(
-                                ServerConfigOptions.PRINT_EXECUTION_INFO_INTERVAL.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .PRINT_EXECUTION_INFO_INTERVAL
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL
+                    .key()
+                    .equals(name)) {
                 engineConfig.setPrintJobMetricsInfoInterval(
                         getIntegerValue(
-                                ServerConfigOptions.PRINT_JOB_METRICS_INFO_INTERVAL.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .PRINT_JOB_METRICS_INFO_INTERVAL
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL
+                    .key()
+                    .equals(name)) {
                 engineConfig.setJobMetricsBackupInterval(
                         getIntegerValue(
-                                ServerConfigOptions.JOB_METRICS_BACKUP_INTERVAL.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .JOB_METRICS_BACKUP_INTERVAL
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.TASK_EXECUTION_THREAD_SHARE_MODE.key().equals(name)) {
+            } else if (ServerConfigOptions.WorkerServerConfigOptions
+                    .TASK_EXECUTION_THREAD_SHARE_MODE
+                    .key()
+                    .equals(name)) {
                 String mode = getTextContent(node).toUpperCase(Locale.ROOT);
                 if (!Arrays.asList("ALL", "OFF", "PART").contains(mode)) {
                     throw new IllegalArgumentException(
-                            ServerConfigOptions.TASK_EXECUTION_THREAD_SHARE_MODE
+                            ServerConfigOptions.WorkerServerConfigOptions
+                                            .TASK_EXECUTION_THREAD_SHARE_MODE
                                     + " must in [ALL, OFF, PART]");
                 }
                 engineConfig.setTaskExecutionThreadShareMode(ThreadShareMode.valueOf(mode));
-            } else if (ServerConfigOptions.SLOT_SERVICE.key().equals(name)) {
+            } else if (ServerConfigOptions.WorkerServerConfigOptions.SLOT_SERVICE
+                    .key()
+                    .equals(name)) {
                 engineConfig.setSlotServiceConfig(parseSlotServiceConfig(node));
-            } else if (ServerConfigOptions.CHECKPOINT.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT
+                    .key()
+                    .equals(name)) {
                 engineConfig.setCheckpointConfig(parseCheckpointConfig(node));
-            } else if (ServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES
+                    .key()
+                    .equals(name)) {
                 engineConfig.setHistoryJobExpireMinutes(
                         getIntegerValue(
-                                ServerConfigOptions.HISTORY_JOB_EXPIRE_MINUTES.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .HISTORY_JOB_EXPIRE_MINUTES
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_STORAGE_CONFIG.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_STORAGE_CONFIG
+                    .key()
+                    .equals(name)) {
                 engineConfig.setConnectorJarStorageConfig(parseConnectorJarStorageConfig(node));
             } else if (ServerConfigOptions.CLASSLOADER_CACHE_MODE.key().equals(name)) {
                 engineConfig.setClassloaderCacheMode(getBooleanValue(getTextContent(node)));
-            } else if (ServerConfigOptions.EVENT_REPORT_HTTP.equalsIgnoreCase(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.EVENT_REPORT_HTTP
+                    .equalsIgnoreCase(name)) {
                 NamedNodeMap attributes = node.getAttributes();
-                Node urlNode = attributes.getNamedItem(ServerConfigOptions.EVENT_REPORT_HTTP_URL);
+                Node urlNode =
+                        attributes.getNamedItem(
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .EVENT_REPORT_HTTP_URL);
                 if (urlNode != null) {
                     engineConfig.setEventReportHttpApi(getTextContent(urlNode));
                     Node headersNode =
-                            attributes.getNamedItem(ServerConfigOptions.EVENT_REPORT_HTTP_HEADERS);
+                            attributes.getNamedItem(
+                                    ServerConfigOptions.MasterServerConfigOptions
+                                            .EVENT_REPORT_HTTP_HEADERS);
                     if (headersNode != null) {
                         Map<String, String> headers = new LinkedHashMap<>();
                         NodeList nodeList = headersNode.getChildNodes();
@@ -192,12 +239,16 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
                 }
             } else if (ServerConfigOptions.TELEMETRY.key().equals(name)) {
                 engineConfig.setTelemetryConfig(parseTelemetryConfig(node));
-            } else if (ServerConfigOptions.JOB_SCHEDULE_STRATEGY.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.JOB_SCHEDULE_STRATEGY
+                    .key()
+                    .equals(name)) {
                 engineConfig.setScheduleStrategy(
                         ScheduleStrategy.valueOf(getTextContent(node).toUpperCase(Locale.ROOT)));
-            } else if (ServerConfigOptions.HTTP.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.HTTP.key().equals(name)) {
                 engineConfig.setHttpConfig(parseHttpConfig(node));
-            } else if (ServerConfigOptions.COORDINATOR_SERVICE.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.COORDINATOR_SERVICE
+                    .key()
+                    .equals(name)) {
                 engineConfig.setCoordinatorServiceConfig(parseCoordinatorServiceConfig(node));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
@@ -215,22 +266,35 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         CheckpointConfig checkpointConfig = new CheckpointConfig();
         for (Node node : childElements(checkpointNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.CHECKPOINT_INTERVAL.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_INTERVAL
+                    .key()
+                    .equals(name)) {
                 checkpointConfig.setCheckpointInterval(
                         getIntegerValue(
-                                ServerConfigOptions.CHECKPOINT_INTERVAL.key(),
+                                ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_INTERVAL
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CHECKPOINT_TIMEOUT.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_TIMEOUT
+                    .key()
+                    .equals(name)) {
                 checkpointConfig.setCheckpointTimeout(
                         getIntegerValue(
-                                ServerConfigOptions.CHECKPOINT_TIMEOUT.key(),
+                                ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_TIMEOUT
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.SCHEMA_CHANGE_CHECKPOINT_TIMEOUT.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions
+                    .SCHEMA_CHANGE_CHECKPOINT_TIMEOUT
+                    .key()
+                    .equals(name)) {
                 checkpointConfig.setSchemaChangeCheckpointTimeout(
                         getIntegerValue(
-                                ServerConfigOptions.SCHEMA_CHANGE_CHECKPOINT_TIMEOUT.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .SCHEMA_CHANGE_CHECKPOINT_TIMEOUT
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CHECKPOINT_STORAGE.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_STORAGE
+                    .key()
+                    .equals(name)) {
                 checkpointConfig.setStorage(parseCheckpointStorageConfig(node));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
@@ -244,14 +308,23 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         CheckpointStorageConfig checkpointStorageConfig = new CheckpointStorageConfig();
         for (Node node : childElements(checkpointStorageConfigNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.CHECKPOINT_STORAGE_TYPE.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_STORAGE_TYPE
+                    .key()
+                    .equals(name)) {
                 checkpointStorageConfig.setStorage(getTextContent(node));
-            } else if (ServerConfigOptions.CHECKPOINT_STORAGE_MAX_RETAINED.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CHECKPOINT_STORAGE_MAX_RETAINED
+                    .key()
+                    .equals(name)) {
                 checkpointStorageConfig.setMaxRetainedCheckpoints(
                         getIntegerValue(
-                                ServerConfigOptions.CHECKPOINT_STORAGE_MAX_RETAINED.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .CHECKPOINT_STORAGE_MAX_RETAINED
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CHECKPOINT_STORAGE_PLUGIN_CONFIG.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions
+                    .CHECKPOINT_STORAGE_PLUGIN_CONFIG
+                    .key()
+                    .equals(name)) {
                 Map<String, String> pluginConfig = parseCheckpointPluginConfig(node);
                 checkpointStorageConfig.setStoragePluginConfig(pluginConfig);
             } else {
@@ -281,30 +354,47 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         ConnectorJarStorageConfig connectorJarStorageConfig = new ConnectorJarStorageConfig();
         for (Node node : childElements(connectorJarStorageConfigNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.ENABLE_CONNECTOR_JAR_STORAGE.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.ENABLE_CONNECTOR_JAR_STORAGE
+                    .key()
+                    .equals(name)) {
                 connectorJarStorageConfig.setEnable(getBooleanValue(getTextContent(node)));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_STORAGE_MODE.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_STORAGE_MODE
+                    .key()
+                    .equals(name)) {
                 String mode = getTextContent(node).toUpperCase();
                 if (StringUtils.isNotBlank(mode)
                         && !Arrays.asList("SHARED", "ISOLATED").contains(mode)) {
                     throw new IllegalArgumentException(
-                            ServerConfigOptions.CONNECTOR_JAR_STORAGE_MODE
+                            ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_STORAGE_MODE
                                     + " must in [SHARED, ISOLATED]");
                 }
                 connectorJarStorageConfig.setStorageMode(ConnectorJarStorageMode.valueOf(mode));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_STORAGE_PATH.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_STORAGE_PATH
+                    .key()
+                    .equals(name)) {
                 connectorJarStorageConfig.setStoragePath(getTextContent(node));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_CLEANUP_TASK_INTERVAL.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions
+                    .CONNECTOR_JAR_CLEANUP_TASK_INTERVAL
+                    .key()
+                    .equals(name)) {
                 connectorJarStorageConfig.setCleanupTaskInterval(
                         getIntegerValue(
-                                ServerConfigOptions.CONNECTOR_JAR_CLEANUP_TASK_INTERVAL.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .CONNECTOR_JAR_CLEANUP_TASK_INTERVAL
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_EXPIRY_TIME.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_EXPIRY_TIME
+                    .key()
+                    .equals(name)) {
                 connectorJarStorageConfig.setConnectorJarExpiryTime(
                         getIntegerValue(
-                                ServerConfigOptions.CONNECTOR_JAR_EXPIRY_TIME.key(),
+                                ServerConfigOptions.MasterServerConfigOptions
+                                        .CONNECTOR_JAR_EXPIRY_TIME
+                                        .key(),
                                 getTextContent(node)));
-            } else if (ServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_CONFIG.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_CONFIG
+                    .key()
+                    .equals(name)) {
                 connectorJarStorageConfig.setConnectorJarHAStorageConfig(
                         parseConnectorJarHAStorageConfig(node));
             } else {
@@ -319,16 +409,20 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         ConnectorJarHAStorageConfig connectorJarHAStorageConfig = new ConnectorJarHAStorageConfig();
         for (Node node : childElements(connectorJarHAStorageConfigNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_TYPE.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_TYPE
+                    .key()
+                    .equals(name)) {
                 String type = getTextContent(node);
                 if (StringUtils.isNotBlank(type)
                         && !Arrays.asList("localfile", "hdfs").contains(type)) {
                     throw new IllegalArgumentException(
-                            ServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_TYPE
+                            ServerConfigOptions.MasterServerConfigOptions
+                                            .CONNECTOR_JAR_HA_STORAGE_TYPE
                                     + " must in [localfile, hdfs]");
                 }
                 connectorJarHAStorageConfig.setType(type);
-            } else if (ServerConfigOptions.CONNECTOR_JAR_HA_STORAGE_PLUGIN_CONFIG
+            } else if (ServerConfigOptions.MasterServerConfigOptions
+                    .CONNECTOR_JAR_HA_STORAGE_PLUGIN_CONFIG
                     .key()
                     .equals(name)) {
                 Map<String, String> connectorJarHAStoragePluginConfig =
@@ -400,19 +494,30 @@ public class YamlSeaTunnelDomConfigProcessor extends AbstractDomConfigProcessor
         HttpConfig httpConfig = new HttpConfig();
         for (Node node : childElements(httpNode)) {
             String name = cleanNodeName(node);
-            if (ServerConfigOptions.PORT.key().equals(name)) {
+            if (ServerConfigOptions.MasterServerConfigOptions.PORT.key().equals(name)) {
                 httpConfig.setPort(
-                        getIntegerValue(ServerConfigOptions.PORT.key(), getTextContent(node)));
-            } else if (ServerConfigOptions.CONTEXT_PATH.key().equals(name)) {
+                        getIntegerValue(
+                                ServerConfigOptions.MasterServerConfigOptions.PORT.key(),
+                                getTextContent(node)));
+            } else if (ServerConfigOptions.MasterServerConfigOptions.CONTEXT_PATH
+                    .key()
+                    .equals(name)) {
                 httpConfig.setContextPath(getTextContent(node));
-            } else if (ServerConfigOptions.ENABLE_HTTP.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.ENABLE_HTTP
+                    .key()
+                    .equals(name)) {
                 httpConfig.setEnabled(getBooleanValue(getTextContent(node)));
-            } else if (ServerConfigOptions.ENABLE_DYNAMIC_PORT.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.ENABLE_DYNAMIC_PORT
+                    .key()
+                    .equals(name)) {
                 httpConfig.setEnableDynamicPort(getBooleanValue(getTextContent(node)));
-            } else if (ServerConfigOptions.PORT_RANGE.key().equals(name)) {
+            } else if (ServerConfigOptions.MasterServerConfigOptions.PORT_RANGE
+                    .key()
+                    .equals(name)) {
                 httpConfig.setPortRange(
                         getIntegerValue(
-                                ServerConfigOptions.PORT_RANGE.key(), getTextContent(node)));
+                                ServerConfigOptions.MasterServerConfigOptions.PORT_RANGE.key(),
+                                getTextContent(node)));
             } else {
                 LOGGER.warning("Unrecognized element: " + name);
             }
