@@ -33,7 +33,6 @@ import lombok.extern.slf4j.Slf4j;
 import java.io.IOException;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
-import java.util.Map;
 import java.util.Set;
 
 /**
@@ -59,7 +58,7 @@ public class LogicalDag implements IdentifiedDataSerializable {
 
     @Getter private JobConfig jobConfig;
     private final Set<LogicalEdge> edges = new LinkedHashSet<>();
-    private final Map<Long, LogicalVertex> logicalVertexMap = new LinkedHashMap<>();
+    private final LinkedHashMap<Long, LogicalVertex> logicalVertexMap = new LinkedHashMap<>();
     private IdGenerator idGenerator;
     private boolean isStartWithSavePoint = false;
 
@@ -82,7 +81,7 @@ public class LogicalDag implements IdentifiedDataSerializable {
         return this.edges;
     }
 
-    public Map<Long, LogicalVertex> getLogicalVertexMap() {
+    public LinkedHashMap<Long, LogicalVertex> getLogicalVertexMap() {
         return logicalVertexMap;
     }
 
@@ -116,8 +115,18 @@ public class LogicalDag implements IdentifiedDataSerializable {
                 .forEach(
                         e -> {
                             JsonObject edge = new JsonObject();
-                            edge.add("inputVertex", e.getInputVertex().getAction().getName());
-                            edge.add("targetVertex", e.getTargetVertex().getAction().getName());
+                            edge.add(
+                                    "inputVertex",
+                                    logicalVertexMap
+                                            .get(e.getInputVertexId())
+                                            .getAction()
+                                            .getName());
+                            edge.add(
+                                    "targetVertex",
+                                    logicalVertexMap
+                                            .get(e.getTargetVertexId())
+                                            .getAction()
+                                            .getName());
                             edges.add(edge);
                         });
 
@@ -137,13 +146,6 @@ public class LogicalDag implements IdentifiedDataSerializable {
 
     @Override
     public void writeData(ObjectDataOutput out) throws IOException {
-        out.writeInt(logicalVertexMap.size());
-
-        for (Map.Entry<Long, LogicalVertex> entry : logicalVertexMap.entrySet()) {
-            out.writeLong(entry.getKey());
-            out.writeObject(entry.getValue());
-        }
-
         out.writeInt(edges.size());
 
         for (LogicalEdge edge : edges) {
@@ -158,19 +160,11 @@ public class LogicalDag implements IdentifiedDataSerializable {
 
     @Override
     public void readData(ObjectDataInput in) throws IOException {
-        int vertexCount = in.readInt();
-
-        for (int i = 0; i < vertexCount; i++) {
-            Long key = in.readLong();
-            LogicalVertex value = in.readObject();
-            logicalVertexMap.put(key, value);
-        }
 
         int edgeCount = in.readInt();
 
         for (int i = 0; i < edgeCount; i++) {
             LogicalEdge edge = in.readObject();
-            edge.recoveryFromVertexMap(logicalVertexMap);
             edges.add(edge);
         }
 
