@@ -23,19 +23,23 @@ import org.apache.seatunnel.engine.common.Constant;
 import org.apache.seatunnel.engine.common.exception.SeaTunnelEngineException;
 import org.apache.seatunnel.engine.common.utils.ExceptionUtil;
 import org.apache.seatunnel.engine.common.utils.PassiveCompletableFuture;
+import org.apache.seatunnel.engine.common.utils.concurrent.CompletableFuture;
 import org.apache.seatunnel.engine.core.job.JobImmutableInformation;
 import org.apache.seatunnel.engine.core.job.JobResult;
 import org.apache.seatunnel.engine.core.job.JobStatus;
 import org.apache.seatunnel.engine.core.job.PipelineExecutionState;
 import org.apache.seatunnel.engine.core.job.PipelineStatus;
+import org.apache.seatunnel.engine.server.execution.TaskGroupLocation;
 import org.apache.seatunnel.engine.server.master.JobMaster;
+import org.apache.seatunnel.engine.server.resourcemanager.resource.SlotProfile;
 
 import com.hazelcast.map.IMap;
 import lombok.NonNull;
 import lombok.extern.slf4j.Slf4j;
 
+import java.util.HashMap;
 import java.util.List;
-import java.util.concurrent.CompletableFuture;
+import java.util.Map;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicReference;
@@ -75,6 +79,9 @@ public class PhysicalPlan {
 
     private JobMaster jobMaster;
 
+    private Map<TaskGroupLocation, CompletableFuture<SlotProfile>> preApplyResourceFutures =
+            new HashMap<>();
+
     /** Whether we make the job end when pipeline turn to end state. */
     private boolean makeJobEndWhenPipelineEnded = true;
 
@@ -303,6 +310,7 @@ public class PhysicalPlan {
             case CREATED:
                 updateJobState(JobStatus.SCHEDULED);
                 break;
+            case PENDING:
             case SCHEDULED:
                 getPipelineList()
                         .forEach(
@@ -333,4 +341,17 @@ public class PhysicalPlan {
                 throw new IllegalArgumentException("Unknown Job State: " + getJobStatus());
         }
     }
+
+    public void completeJobEndFuture(JobResult jobResult) {
+        jobEndFuture.complete(jobResult);
+    }
+
+    public Map<TaskGroupLocation, CompletableFuture<SlotProfile>> getPreApplyResourceFutures() {
+        return preApplyResourceFutures;
+    }
+
+    public void setPreApplyResourceFutures(
+            Map<TaskGroupLocation, CompletableFuture<SlotProfile>> preApplyResourceFutures) {
+        this.preApplyResourceFutures = preApplyResourceFutures;
+    }
 }
