@@ -17,62 +17,92 @@
 
 package org.apache.seatunnel.engine.server.dag.physical;
 
+import org.apache.seatunnel.common.utils.ExceptionUtils;
+import org.apache.seatunnel.engine.common.utils.concurrent.CompletableFuture;
 import org.apache.seatunnel.engine.server.execution.TaskGroupLocation;
+import org.apache.seatunnel.engine.server.master.JobMaster;
 import org.apache.seatunnel.engine.server.resourcemanager.NoEnoughResourceException;
 import org.apache.seatunnel.engine.server.resourcemanager.ResourceManager;
 import org.apache.seatunnel.engine.server.resourcemanager.resource.ResourceProfile;
 import org.apache.seatunnel.engine.server.resourcemanager.resource.SlotProfile;
 
+import com.hazelcast.logging.ILogger;
+import com.hazelcast.logging.Logger;
 import lombok.NonNull;
 
 import java.util.HashMap;
 import java.util.Map;
-import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.CompletionException;
 
 public class ResourceUtils {
 
+    private static final ILogger LOGGER = Logger.getLogger(ResourceUtils.class);
+
     public static void applyResourceForPipeline(
-            @NonNull ResourceManager resourceManager, @NonNull SubPlan subPlan) {
+            @NonNull JobMaster jobMaster, @NonNull SubPlan subPlan) {
+
         Map<TaskGroupLocation, CompletableFuture<SlotProfile>> futures = new HashMap<>();
         Map<TaskGroupLocation, SlotProfile> slotProfiles = new HashMap<>();
-        // TODO If there is no enough resources for tasks, we need add some wait profile
-        subPlan.getCoordinatorVertexList()
-                .forEach(
-                        coordinator ->
-                                futures.put(
-                                        coordinator.getTaskGroupLocation(),
-                                        applyResourceForTask(
-                                                resourceManager, coordinator, subPlan.getTags())));
+        Map<TaskGroupLocation, CompletableFuture<SlotProfile>> preApplyResourceFutures =
+                jobMaster.getPhysicalPlan().getPreApplyResourceFutures();
 
-        subPlan.getPhysicalVertexList()
-                .forEach(
-                        task ->
-                                futures.put(
-                                        task.getTaskGroupLocation(),
-                                        applyResourceForTask(
-                                                resourceManager, task, subPlan.getTags())));
+        // TODO If there is no enough resources for tasks, we need add some wait profile
+        allocateResources(subPlan, futures, preApplyResourceFutures);
 
         futures.forEach(
                 (key, value) -> {
                     try {
                         slotProfiles.put(key, value == null ? null : value.join());
                     } catch (CompletionException e) {
-                        // do nothing
+                        LOGGER.warning("Failed to join future for task group location: " + key, e);
                     }
                 });
+
         // set it first, avoid can't get it when get resource not enough exception and need release
         // applied resource
         subPlan.getJobMaster().setOwnedSlotProfiles(subPlan.getPipelineLocation(), slotProfiles);
+
         if (futures.size() != slotProfiles.size()) {
             throw new NoEnoughResourceException();
         }
     }
 
+    private static void allocateResources(
+            SubPlan subPlan,
+            Map<TaskGroupLocation, CompletableFuture<SlotProfile>> futures,
+            Map<TaskGroupLocation, CompletableFuture<SlotProfile>> preApplyResourceFutures) {
+        subPlan.getCoordinatorVertexList()
+                .forEach(
+                        coordinator -> {
+                            TaskGroupLocation taskGroupLocation =
+                                    coordinator.getTaskGroupLocation();
+                            futures.put(
+                                    taskGroupLocation,
+                                    preApplyResourceFutures.get(taskGroupLocation));
+                        });
+
+        subPlan.getPhysicalVertexList()
+                .forEach(
+                        task -> {
+                            TaskGroupLocation taskGroupLocation = task.getTaskGroupLocation();
+                            futures.put(
+                                    taskGroupLocation,
+                                    preApplyResourceFutures.get(taskGroupLocation));
+                        });
+    }
+
     public static CompletableFuture<SlotProfile> applyResourceForTask(
             ResourceManager resourceManager, PhysicalVertex task, Map<String, String> tags) {
         // TODO custom resource size
-        return resourceManager.applyResource(
-                task.getTaskGroupLocation().getJobId(), new ResourceProfile(), tags);
+        try {
+            return resourceManager.applyResource(
+                    task.getTaskGroupLocation().getJobId(), new ResourceProfile(), tags);
+        } catch (NoEnoughResourceException e) {
+            LOGGER.severe(
+                    String.format(
+                            "Job Resource not enough, jobId: %s, message: %s",
+                            task.getTaskGroupLocation().getJobId(), ExceptionUtils.getMessage(e)));
+            return null;
+        }
     }
 }
