@@ -18,6 +18,7 @@
 package org.apache.seatunnel.engine.server.resourcemanager.thirdparty.kubernetes;
 
 import org.apache.seatunnel.engine.common.config.EngineConfig;
+import org.apache.seatunnel.engine.common.utils.concurrent.CompletableFuture;
 import org.apache.seatunnel.engine.server.resourcemanager.AbstractResourceManager;
 import org.apache.seatunnel.engine.server.resourcemanager.resource.ResourceProfile;
 import org.apache.seatunnel.engine.server.resourcemanager.thirdparty.CreateWorkerResult;
@@ -25,8 +26,6 @@ import org.apache.seatunnel.engine.server.resourcemanager.thirdparty.ThirdPartyR
 
 import com.hazelcast.spi.impl.NodeEngine;
 
-import java.util.concurrent.CompletableFuture;
-
 public class KubernetesResourceManager extends AbstractResourceManager
         implements ThirdPartyResourceManager {
 
