@@ -26,11 +26,17 @@ import org.apache.seatunnel.core.starter.utils.ConfigBuilder;
 import org.apache.seatunnel.engine.server.rest.RestConstant;
 
 import com.hazelcast.internal.util.StringUtil;
+import scala.Tuple2;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
+import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
+import java.util.stream.StreamSupport;
+
+import static org.apache.seatunnel.engine.common.Constant.REST_SUBMIT_JOBS_PARAMS;
 
 public class RestUtil {
     private RestUtil() {}
@@ -67,6 +73,21 @@ public class RestUtil {
 
     public static Config buildConfig(JsonNode jsonNode, boolean isEncrypt) {
         Map<String, Object> objectMap = JsonUtils.toMap(jsonNode);
-        return ConfigBuilder.of(objectMap, isEncrypt);
+        return ConfigBuilder.of(objectMap, isEncrypt, true);
+    }
+
+    public static List<Tuple2<Map<String, String>, Config>> buildConfigList(
+            JsonNode jsonNode, boolean isEncrypt) {
+        return StreamSupport.stream(jsonNode.spliterator(), false)
+                .filter(JsonNode::isObject)
+                .map(
+                        node -> {
+                            Map<String, Object> nodeMap = JsonUtils.toMap(node);
+                            Map<String, String> params =
+                                    (Map<String, String>) nodeMap.remove(REST_SUBMIT_JOBS_PARAMS);
+                            Config config = ConfigBuilder.of(nodeMap, isEncrypt, true);
+                            return new Tuple2<>(params, config);
+                        })
+                .collect(Collectors.toList());
     }
 }
