@@ -144,8 +144,8 @@ public class CoordinatorServiceTest {
                 new JobImmutableInformation(
                         jobId,
                         "Test",
-                        coordinatorServiceTest.getSerializationService().toData(testLogicalDag),
-                        testLogicalDag.getJobConfig(),
+                        coordinatorServiceTest.getSerializationService(),
+                        testLogicalDag,
                         Collections.emptyList(),
                         Collections.emptyList());
 
@@ -208,8 +208,8 @@ public class CoordinatorServiceTest {
                 new JobImmutableInformation(
                         jobId,
                         "Test",
-                        instance1.getSerializationService().toData(testLogicalDag),
-                        testLogicalDag.getJobConfig(),
+                        instance1.getSerializationService(),
+                        testLogicalDag,
                         Collections.emptyList(),
                         Collections.emptyList());
 
