@@ -19,11 +19,11 @@ package org.apache.seatunnel.transform.fieldmapper;
 
 import org.apache.seatunnel.api.configuration.ReadonlyConfig;
 import org.apache.seatunnel.api.configuration.util.OptionRule;
-import org.apache.seatunnel.api.table.catalog.CatalogTable;
 import org.apache.seatunnel.api.table.connector.TableTransform;
 import org.apache.seatunnel.api.table.factory.Factory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactory;
 import org.apache.seatunnel.api.table.factory.TableTransformFactoryContext;
+import org.apache.seatunnel.transform.common.TransformCommonOptions;
 
 import com.google.auto.service.AutoService;
 
@@ -36,15 +36,16 @@ public class FieldMapperTransformFactory implements TableTransformFactory {
 
     @Override
     public OptionRule optionRule() {
-        return OptionRule.builder().required(FieldMapperTransformConfig.FIELD_MAPPER).build();
+        return OptionRule.builder()
+                .optional(FieldMapperTransformConfig.FIELD_MAPPER)
+                .optional(TransformCommonOptions.MULTI_TABLES)
+                .optional(TransformCommonOptions.TABLE_MATCH_REGEX)
+                .build();
     }
 
     @Override
     public TableTransform createTransform(TableTransformFactoryContext context) {
-        CatalogTable catalogTable = context.getCatalogTables().get(0);
         ReadonlyConfig options = context.getOptions();
-        FieldMapperTransformConfig fieldMapperTransformConfig =
-                FieldMapperTransformConfig.of(options);
-        return () -> new FieldMapperTransform(fieldMapperTransformConfig, catalogTable);
+        return () -> new FieldMapperMultiCatalogTransform(context.getCatalogTables(), options);
     }
 }
